/**
 * @version working
 * @author Thomas Kriegelstein
 * $Id: PKIPanel.java,v 1.10 2003/12/16 08:36:58 tk4 Exp $
 */
package pki;

import java.awt.BorderLayout;
import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;
import java.util.Properties;

import javax.swing.*;

/**
 * PKI User Interface
 *
 * @author Thomas Kriegelstein
 * @version $Id: PKIPanel.java,v 1.10 2003/12/16 08:36:58 tk4 Exp $
 */
public class PKIPanel
	extends javax.swing.JPanel
	implements java.awt.event.ActionListener, java.awt.event.ItemListener {

	private PKIDatabase database = null;
	private PKICert certifier = null;
	private Properties settings = null;

	private JLabel messageLabel = new JLabel("");
	private JFrame parentFrame = null;

	private JMenuItem settingsItem = null;
	private JMenuItem stopPKIItem = null;
	private PKISettingsDialog psp = null;

	public void setDatabase(PKIDatabase data) {
		database = data;
	}

	public void setCertifier(PKICert cert) {
		certifier = cert;
	}

	public void setStarted() {
		// show the gui for building certificates
		parentFrame.getContentPane().removeAll();
		parentFrame.getContentPane().add(this);
		parentFrame.pack();
		parentFrame.show();
	}

	public void setStopped(String message) {
		// show a panel with the given message
		messageLabel.setText(message);
		parentFrame.getContentPane().removeAll();
		parentFrame.getContentPane().setLayout(new BorderLayout());
		parentFrame.getContentPane().add(
			new JLabel("                                               "),
			BorderLayout.NORTH);
		parentFrame.getContentPane().add(
			new JLabel("                                               "),
			BorderLayout.SOUTH);
		parentFrame.getContentPane().add(
			new JLabel("      "),
			BorderLayout.EAST);
		parentFrame.getContentPane().add(
			new JLabel("      "),
			BorderLayout.WEST);
		parentFrame.getContentPane().add(messageLabel, BorderLayout.CENTER);
		if ((parentFrame.getSize().height < 400)
			|| (parentFrame.getSize().width < 300)) {
			parentFrame.setSize(300, 400);
		}
		parentFrame.pack();
		parentFrame.show();
	}

	public boolean start() {
		boolean result = true;
		parentFrame = new javax.swing.JFrame("Identity - CA");
		parentFrame.addWindowListener(windowAdapter);
		// create menubar
		JMenuBar mbar = new JMenuBar();
		JMenu optionsMenu = new JMenu("Options");
		mbar.add(optionsMenu);
		settingsItem = new JMenuItem("Settings");
		optionsMenu.add(settingsItem);
		optionsMenu.add(new JSeparator());
		stopPKIItem = new JMenuItem("Exit");
		optionsMenu.add(stopPKIItem);
		parentFrame.setJMenuBar(mbar);
		settingsItem.addActionListener(this);
		stopPKIItem.addActionListener(this);
		// show staring screen
		setStopped("<html>Initializing ...</html>");
		return result;
	}

	private static class PKIModel {
		public java.security.cert.X509Certificate identity = null;
		public java.util.Properties info = null;
		public java.security.cert.X509Certificate certificate = null;
	}

	private PKIModel personModel = new PKIModel();
	//private PKIModel roleModel      = new PKIModel();
	//private PKIModel pseudonymModel = new PKIModel();

	/** Creates new form PKI */
	public PKIPanel(Properties settings) {
		this.settings = settings;
		initComponents();
		personMainButton.addActionListener(this);
		roleMainButton.addActionListener(this);
		pseudonymMainButton.addActionListener(this);
		mainPersonButton.addActionListener(this);
		mainRoleButton.addActionListener(this);
		mainPseudonymButton.addActionListener(this);
		mainExitButton.addActionListener(this);
		personFileSelector.addItemListener(this);
		personStoreSelector.addItemListener(this);
		roleDatabaseSelector.addItemListener(this);
		roleFileSelector.addItemListener(this);
		roleStoreSelector.addItemListener(this);
		pseudonymDatabaseSelector.addItemListener(this);
		pseudonymFileSelector.addItemListener(this);
		pseudonymStoreSelector.addItemListener(this);
		personGroup.add(personFileSelector);
		personGroup.add(personStoreSelector);
		roleGroup.add(roleFileSelector);
		roleGroup.add(roleStoreSelector);
		roleGroup.add(roleDatabaseSelector);
		pseudonymGroup.add(pseudonymFileSelector);
		pseudonymGroup.add(pseudonymStoreSelector);
		pseudonymGroup.add(pseudonymDatabaseSelector);
		personLoadButton.addActionListener(this);
		roleLoadButton.addActionListener(this);
		pseudonymLoadButton.addActionListener(this);
		personInfoButton.addActionListener(this);
		roleInfoButton.addActionListener(this);
		pseudonymInfoButton.addActionListener(this);
		personSignButton.addActionListener(this);
		roleSignButton.addActionListener(this);
		pseudonymSignButton.addActionListener(this);
		personSaveButton.addActionListener(this);
		roleSaveButton.addActionListener(this);
		pseudonymSaveButton.addActionListener(this);
		personAliasButton.addActionListener(this);
	}

	private javax.swing.ButtonGroup personGroup = new javax.swing.ButtonGroup();
	private javax.swing.ButtonGroup roleGroup = new javax.swing.ButtonGroup();
	private javax.swing.ButtonGroup pseudonymGroup =
		new javax.swing.ButtonGroup();

	public static void main(String[] args) {
		javax.swing.JFrame frame = new javax.swing.JFrame("PKIPanel");
		frame.getContentPane().add(new PKIPanel(new Properties()));
		frame.pack();
		frame.show();
	}

	/** This method is called from within the constructor to
	 * initialize the form.
	 * WARNING: Do NOT modify this code. The content of this method is
	 * always regenerated by the FormEditor.
	 */
	private void initComponents() { //GEN-BEGIN:initComponents
		jPanel2 = new javax.swing.JPanel();
		jLabel2 = new javax.swing.JLabel();
		mainPersonButton = new javax.swing.JButton();
		mainRoleButton = new javax.swing.JButton();
		mainPseudonymButton = new javax.swing.JButton();
		mainExitButton = new javax.swing.JButton();
		jPanel3 = new javax.swing.JPanel();
		jPanel6 = new javax.swing.JPanel();
		jPanel7 = new javax.swing.JPanel();
		personFileSelector = new javax.swing.JRadioButton();
		personStoreSelector = new javax.swing.JRadioButton();
		personLoadPanel = new javax.swing.JPanel();
		jPanel9 = new javax.swing.JPanel();
		jLabel3 = new javax.swing.JLabel();
		personFileField = new javax.swing.JTextField();
		personFileButton = new javax.swing.JButton();
		jPanel11 = new javax.swing.JPanel();
		jPanel10 = new javax.swing.JPanel();
		jLabel4 = new javax.swing.JLabel();
		personStoreField = new javax.swing.JTextField();
		personStoreButton = new javax.swing.JButton();
		jLabel5 = new javax.swing.JLabel();
		personAliasBox = new javax.swing.JComboBox();
		personAliasButton = new javax.swing.JButton();
		personLoadButton = new javax.swing.JButton();
		jPanel12 = new javax.swing.JPanel();
		jPanel15 = new javax.swing.JPanel();
		jLabel12 = new javax.swing.JLabel();
		personInfoCNField = new javax.swing.JTextField();
		jLabel13 = new javax.swing.JLabel();
		personInfoOUField = new javax.swing.JTextField();
		jLabel14 = new javax.swing.JLabel();
		personInfoOField = new javax.swing.JTextField();
		jLabel15 = new javax.swing.JLabel();
		personInfoHashField = new javax.swing.JTextField();
		jLabel17 = new javax.swing.JLabel();
		personInfoLField = new javax.swing.JTextField();
		jLabel18 = new javax.swing.JLabel();
		personInfoSTField = new javax.swing.JTextField();
		jLabel19 = new javax.swing.JLabel();
		personInfoCField = new javax.swing.JTextField();
		personInfoButton = new javax.swing.JButton();
		jPanel13 = new javax.swing.JPanel();
		jLabel10 = new javax.swing.JLabel();
		personSignField = new javax.swing.JPasswordField();
		personSignButton = new javax.swing.JButton();
		jPanel14 = new javax.swing.JPanel();
		jLabel11 = new javax.swing.JLabel();
		personCertField = new javax.swing.JTextField();
		personCertButton = new javax.swing.JButton();
		jLabel35 = new javax.swing.JLabel();
		personSerialField = new javax.swing.JTextField();
		personSaveButton = new javax.swing.JButton();
		jPanel16 = new javax.swing.JPanel();
		personMainButton = new javax.swing.JButton();
		jPanel4 = new javax.swing.JPanel();
		jPanel17 = new javax.swing.JPanel();
		jPanel18 = new javax.swing.JPanel();
		roleDatabaseSelector = new javax.swing.JRadioButton();
		roleFileSelector = new javax.swing.JRadioButton();
		roleStoreSelector = new javax.swing.JRadioButton();
		roleLoadPanel = new javax.swing.JPanel();
		jPanel25 = new javax.swing.JPanel();
		jLabel31 = new javax.swing.JLabel();
		roleSerialField = new javax.swing.JTextField();
		jPanel26 = new javax.swing.JPanel();
		jPanel20 = new javax.swing.JPanel();
		jLabel21 = new javax.swing.JLabel();
		roleFileField = new javax.swing.JTextField();
		roleFileButton = new javax.swing.JButton();
		jPanel21 = new javax.swing.JPanel();
		jPanel22 = new javax.swing.JPanel();
		jLabel22 = new javax.swing.JLabel();
		roleStoreField = new javax.swing.JTextField();
		roleStoreButton = new javax.swing.JButton();
		jLabel23 = new javax.swing.JLabel();
		roleAliasBox = new javax.swing.JComboBox();
		roleAliasButton = new javax.swing.JButton();
		roleLoadButton = new javax.swing.JButton();
		jPanel23 = new javax.swing.JPanel();
		jPanel24 = new javax.swing.JPanel();
		jLabel24 = new javax.swing.JLabel();
		roleInfoCNField = new javax.swing.JTextField();
		jLabel25 = new javax.swing.JLabel();
		roleInfoOUField = new javax.swing.JTextField();
		jLabel26 = new javax.swing.JLabel();
		roleInfoOField = new javax.swing.JTextField();
		jLabel27 = new javax.swing.JLabel();
		roleInfoHashField = new javax.swing.JTextField();
		jLabel28 = new javax.swing.JLabel();
		roleInfoLField = new javax.swing.JTextField();
		jLabel29 = new javax.swing.JLabel();
		roleInfoSTField = new javax.swing.JTextField();
		jLabel30 = new javax.swing.JLabel();
		roleInfoCField = new javax.swing.JTextField();
		roleInfoButton = new javax.swing.JButton();
		jPanel27 = new javax.swing.JPanel();
		jLabel32 = new javax.swing.JLabel();
		roleSignField = new javax.swing.JPasswordField();
		jLabel34 = new javax.swing.JLabel();
		roleRoleField = new javax.swing.JPasswordField();
		roleSignButton = new javax.swing.JButton();
		jPanel28 = new javax.swing.JPanel();
		jLabel33 = new javax.swing.JLabel();
		roleCertField = new javax.swing.JTextField();
		roleCertButton = new javax.swing.JButton();
		roleSaveButton = new javax.swing.JButton();
		jPanel29 = new javax.swing.JPanel();
		roleMainButton = new javax.swing.JButton();
		jPanel5 = new javax.swing.JPanel();
		jPanel30 = new javax.swing.JPanel();
		jPanel31 = new javax.swing.JPanel();
		pseudonymDatabaseSelector = new javax.swing.JRadioButton();
		pseudonymFileSelector = new javax.swing.JRadioButton();
		pseudonymStoreSelector = new javax.swing.JRadioButton();
		pseudonymLoadPanel = new javax.swing.JPanel();
		jPanel33 = new javax.swing.JPanel();
		jLabel36 = new javax.swing.JLabel();
		pseudonymSerialField = new javax.swing.JTextField();
		jPanel34 = new javax.swing.JPanel();
		jPanel35 = new javax.swing.JPanel();
		jLabel37 = new javax.swing.JLabel();
		pseudonymFileField = new javax.swing.JTextField();
		pseudonymFileButton = new javax.swing.JButton();
		jPanel36 = new javax.swing.JPanel();
		jPanel37 = new javax.swing.JPanel();
		jLabel38 = new javax.swing.JLabel();
		pseudonymStoreField = new javax.swing.JTextField();
		pseudonymStoreButton = new javax.swing.JButton();
		jLabel39 = new javax.swing.JLabel();
		pseudonymAliasBox = new javax.swing.JComboBox();
		pseudonymAliasButton = new javax.swing.JButton();
		pseudonymLoadButton = new javax.swing.JButton();
		jPanel38 = new javax.swing.JPanel();
		jPanel39 = new javax.swing.JPanel();
		jLabel40 = new javax.swing.JLabel();
		pseudonymInfoCNField = new javax.swing.JTextField();
		jLabel41 = new javax.swing.JLabel();
		pseudonymInfoOUField = new javax.swing.JTextField();
		jLabel42 = new javax.swing.JLabel();
		pseudonymInfoOField = new javax.swing.JTextField();
		jLabel43 = new javax.swing.JLabel();
		pseudonymInfoHashField = new javax.swing.JTextField();
		jLabel44 = new javax.swing.JLabel();
		pseudonymInfoLField = new javax.swing.JTextField();
		jLabel45 = new javax.swing.JLabel();
		pseudonymInfoSTField = new javax.swing.JTextField();
		jLabel46 = new javax.swing.JLabel();
		pseudonymInfoCField = new javax.swing.JTextField();
		pseudonymInfoButton = new javax.swing.JButton();
		jPanel40 = new javax.swing.JPanel();
		jLabel47 = new javax.swing.JLabel();
		pseudonymSignField = new javax.swing.JPasswordField();
		pseudonymSignButton = new javax.swing.JButton();
		jPanel41 = new javax.swing.JPanel();
		jLabel48 = new javax.swing.JLabel();
		pseudonymCertField = new javax.swing.JTextField();
		pseudonymCertButton = new javax.swing.JButton();
		pseudonymSaveButton = new javax.swing.JButton();
		jPanel42 = new javax.swing.JPanel();
		pseudonymMainButton = new javax.swing.JButton();
		jLabel1 = new javax.swing.JLabel();

		setLayout(new java.awt.CardLayout());

		jPanel2.setLayout(new java.awt.GridBagLayout());
		java.awt.GridBagConstraints gridBagConstraints1;

		jLabel2.setText("Bitte ausw\u00e4hlen:");
		jLabel2.setFont(new java.awt.Font("Dialog", 1, 14));
		gridBagConstraints1 = new java.awt.GridBagConstraints();
		jPanel2.add(jLabel2, gridBagConstraints1);

		mainPersonButton.setText("1) Personenpseudonym ausstellen");
		mainPersonButton.setHorizontalAlignment(
			javax.swing.SwingConstants.LEFT);
		gridBagConstraints1 = new java.awt.GridBagConstraints();
		gridBagConstraints1.gridx = 0;
		gridBagConstraints1.fill = java.awt.GridBagConstraints.HORIZONTAL;
		jPanel2.add(mainPersonButton, gridBagConstraints1);

		mainRoleButton.setText("2) Rollenpseudonym ausstellen");
		mainRoleButton.setHorizontalAlignment(javax.swing.SwingConstants.LEFT);
		mainRoleButton.setEnabled(false);
		gridBagConstraints1 = new java.awt.GridBagConstraints();
		gridBagConstraints1.gridx = 0;
		gridBagConstraints1.fill = java.awt.GridBagConstraints.HORIZONTAL;
		jPanel2.add(mainRoleButton, gridBagConstraints1);

		mainPseudonymButton.setText("3) Pseudonym beglaubigen");
		mainPseudonymButton.setHorizontalAlignment(
			javax.swing.SwingConstants.LEFT);
		mainPseudonymButton.setEnabled(false);
		gridBagConstraints1 = new java.awt.GridBagConstraints();
		gridBagConstraints1.gridx = 0;
		gridBagConstraints1.fill = java.awt.GridBagConstraints.HORIZONTAL;
		jPanel2.add(mainPseudonymButton, gridBagConstraints1);

		mainExitButton.setText("4) Programmende");
		mainExitButton.setHorizontalAlignment(javax.swing.SwingConstants.LEFT);
		gridBagConstraints1 = new java.awt.GridBagConstraints();
		gridBagConstraints1.gridx = 0;
		gridBagConstraints1.fill = java.awt.GridBagConstraints.HORIZONTAL;
		jPanel2.add(mainExitButton, gridBagConstraints1);

		add(jPanel2, "main");

		jPanel3.setLayout(new java.awt.GridBagLayout());
		java.awt.GridBagConstraints gridBagConstraints2;

		jPanel6.setLayout(new java.awt.GridBagLayout());
		java.awt.GridBagConstraints gridBagConstraints3;

		jPanel6.setBorder(
			new javax.swing.border.TitledBorder(
				"1. Schritt: Public Key ausw\u00e4hlen"));
		personFileSelector.setSelected(true);
		personFileSelector.setText("Datei");
		jPanel7.add(personFileSelector);

		personStoreSelector.setText("Java Key Store");
		jPanel7.add(personStoreSelector);

		gridBagConstraints3 = new java.awt.GridBagConstraints();
		gridBagConstraints3.gridwidth = 2;
		gridBagConstraints3.fill = java.awt.GridBagConstraints.HORIZONTAL;
		jPanel6.add(jPanel7, gridBagConstraints3);

		personLoadPanel.setLayout(new java.awt.CardLayout());

		jPanel9.setLayout(new java.awt.GridBagLayout());
		java.awt.GridBagConstraints gridBagConstraints4;

		jLabel3.setText("Dateiname: ");
		gridBagConstraints4 = new java.awt.GridBagConstraints();
		jPanel9.add(jLabel3, gridBagConstraints4);

		personFileField.setMargin(new java.awt.Insets(2, 2, 2, 2));
		gridBagConstraints4 = new java.awt.GridBagConstraints();
		gridBagConstraints4.fill = java.awt.GridBagConstraints.HORIZONTAL;
		gridBagConstraints4.weightx = 10.0;
		jPanel9.add(personFileField, gridBagConstraints4);

		personFileButton.setText("Ausw\u00e4hlen");
		personFileButton.setMargin(new java.awt.Insets(2, 4, 2, 4));
		gridBagConstraints4 = new java.awt.GridBagConstraints();
		jPanel9.add(personFileButton, gridBagConstraints4);

		gridBagConstraints4 = new java.awt.GridBagConstraints();
		gridBagConstraints4.gridx = 0;
		gridBagConstraints4.fill = java.awt.GridBagConstraints.BOTH;
		gridBagConstraints4.weighty = 1.0;
		jPanel9.add(jPanel11, gridBagConstraints4);

		personLoadPanel.add(jPanel9, "file");

		jPanel10.setLayout(new java.awt.GridBagLayout());
		java.awt.GridBagConstraints gridBagConstraints5;

		jLabel4.setText("Dateiname: ");
		gridBagConstraints5 = new java.awt.GridBagConstraints();
		jPanel10.add(jLabel4, gridBagConstraints5);

		personStoreField.setMargin(new java.awt.Insets(2, 2, 2, 2));
		gridBagConstraints5 = new java.awt.GridBagConstraints();
		gridBagConstraints5.fill = java.awt.GridBagConstraints.HORIZONTAL;
		gridBagConstraints5.weightx = 10.0;
		jPanel10.add(personStoreField, gridBagConstraints5);

		personStoreButton.setText("Ausw\u00e4hlen");
		personStoreButton.setMargin(new java.awt.Insets(2, 4, 2, 4));
		gridBagConstraints5 = new java.awt.GridBagConstraints();
		jPanel10.add(personStoreButton, gridBagConstraints5);

		jLabel5.setText("Aliasname: ");
		gridBagConstraints5 = new java.awt.GridBagConstraints();
		gridBagConstraints5.gridx = 0;
		jPanel10.add(jLabel5, gridBagConstraints5);

		gridBagConstraints5 = new java.awt.GridBagConstraints();
		gridBagConstraints5.gridx = 1;
		gridBagConstraints5.fill = java.awt.GridBagConstraints.HORIZONTAL;
		jPanel10.add(personAliasBox, gridBagConstraints5);

		personAliasButton.setText("Erneuern");
		personAliasButton.setMargin(new java.awt.Insets(2, 4, 2, 4));
		gridBagConstraints5 = new java.awt.GridBagConstraints();
		gridBagConstraints5.gridx = 2;
		gridBagConstraints5.fill = java.awt.GridBagConstraints.HORIZONTAL;
		jPanel10.add(personAliasButton, gridBagConstraints5);

		personLoadPanel.add(jPanel10, "jks");

		gridBagConstraints3 = new java.awt.GridBagConstraints();
		gridBagConstraints3.gridx = 0;
		gridBagConstraints3.gridwidth = 2;
		gridBagConstraints3.fill = java.awt.GridBagConstraints.BOTH;
		gridBagConstraints3.weightx = 10.0;
		jPanel6.add(personLoadPanel, gridBagConstraints3);

		personLoadButton.setFont(new java.awt.Font("Dialog", 1, 11));
		personLoadButton.setText("Laden!");
		gridBagConstraints3 = new java.awt.GridBagConstraints();
		gridBagConstraints3.gridx = 1;
		gridBagConstraints3.gridy = 2;
		gridBagConstraints3.fill = java.awt.GridBagConstraints.HORIZONTAL;
		jPanel6.add(personLoadButton, gridBagConstraints3);

		gridBagConstraints2 = new java.awt.GridBagConstraints();
		gridBagConstraints2.gridx = 0;
		gridBagConstraints2.fill = java.awt.GridBagConstraints.HORIZONTAL;
		gridBagConstraints2.weightx = 10.0;
		jPanel3.add(jPanel6, gridBagConstraints2);

		jPanel12.setLayout(new java.awt.GridBagLayout());
		java.awt.GridBagConstraints gridBagConstraints6;

		jPanel12.setBorder(
			new javax.swing.border.TitledBorder(
				"2. Schritt: Angaben pr\u00fcfen"));
		jPanel15.setLayout(new java.awt.GridBagLayout());
		java.awt.GridBagConstraints gridBagConstraints7;

		jLabel12.setText("Name (CN): ");
		jLabel12.setHorizontalAlignment(javax.swing.SwingConstants.LEFT);
		gridBagConstraints7 = new java.awt.GridBagConstraints();
		gridBagConstraints7.gridx = 0;
		gridBagConstraints7.fill = java.awt.GridBagConstraints.HORIZONTAL;
		jPanel15.add(jLabel12, gridBagConstraints7);

		gridBagConstraints7 = new java.awt.GridBagConstraints();
		gridBagConstraints7.gridx = 1;
		gridBagConstraints7.gridy = 0;
		gridBagConstraints7.fill = java.awt.GridBagConstraints.HORIZONTAL;
		gridBagConstraints7.weightx = 10.0;
		jPanel15.add(personInfoCNField, gridBagConstraints7);

		jLabel13.setText("Abteilung (OU): ");
		jLabel13.setHorizontalAlignment(javax.swing.SwingConstants.LEFT);
		gridBagConstraints7 = new java.awt.GridBagConstraints();
		gridBagConstraints7.gridx = 0;
		gridBagConstraints7.fill = java.awt.GridBagConstraints.HORIZONTAL;
		jPanel15.add(jLabel13, gridBagConstraints7);

		gridBagConstraints7 = new java.awt.GridBagConstraints();
		gridBagConstraints7.gridx = 1;
		gridBagConstraints7.fill = java.awt.GridBagConstraints.HORIZONTAL;
		jPanel15.add(personInfoOUField, gridBagConstraints7);

		jLabel14.setText("Organisation (O): ");
		jLabel14.setHorizontalAlignment(javax.swing.SwingConstants.LEFT);
		gridBagConstraints7 = new java.awt.GridBagConstraints();
		gridBagConstraints7.gridx = 0;
		gridBagConstraints7.fill = java.awt.GridBagConstraints.HORIZONTAL;
		jPanel15.add(jLabel14, gridBagConstraints7);

		gridBagConstraints7 = new java.awt.GridBagConstraints();
		gridBagConstraints7.gridx = 1;
		gridBagConstraints7.fill = java.awt.GridBagConstraints.HORIZONTAL;
		jPanel15.add(personInfoOField, gridBagConstraints7);

		jLabel15.setText("Fingerprint:");
		gridBagConstraints7 = new java.awt.GridBagConstraints();
		gridBagConstraints7.gridx = 0;
		gridBagConstraints7.fill = java.awt.GridBagConstraints.HORIZONTAL;
		jPanel15.add(jLabel15, gridBagConstraints7);

		personInfoHashField.setEditable(false);
		gridBagConstraints7 = new java.awt.GridBagConstraints();
		gridBagConstraints7.gridx = 1;
		gridBagConstraints7.gridy = 3;
		gridBagConstraints7.gridwidth = 3;
		gridBagConstraints7.fill = java.awt.GridBagConstraints.HORIZONTAL;
		jPanel15.add(personInfoHashField, gridBagConstraints7);

		jLabel17.setText(" Stadt (L): ");
		gridBagConstraints7 = new java.awt.GridBagConstraints();
		gridBagConstraints7.gridx = 2;
		gridBagConstraints7.gridy = 0;
		gridBagConstraints7.fill = java.awt.GridBagConstraints.HORIZONTAL;
		jPanel15.add(jLabel17, gridBagConstraints7);

		gridBagConstraints7 = new java.awt.GridBagConstraints();
		gridBagConstraints7.gridx = 3;
		gridBagConstraints7.gridy = 0;
		gridBagConstraints7.fill = java.awt.GridBagConstraints.HORIZONTAL;
		gridBagConstraints7.weightx = 10.0;
		jPanel15.add(personInfoLField, gridBagConstraints7);

		jLabel18.setText(" Bundesland (ST): ");
		gridBagConstraints7 = new java.awt.GridBagConstraints();
		gridBagConstraints7.gridx = 2;
		gridBagConstraints7.fill = java.awt.GridBagConstraints.HORIZONTAL;
		jPanel15.add(jLabel18, gridBagConstraints7);

		gridBagConstraints7 = new java.awt.GridBagConstraints();
		gridBagConstraints7.gridx = 3;
		gridBagConstraints7.fill = java.awt.GridBagConstraints.HORIZONTAL;
		jPanel15.add(personInfoSTField, gridBagConstraints7);

		jLabel19.setText(" L\u00e4nderk\u00fcrzel (C): ");
		gridBagConstraints7 = new java.awt.GridBagConstraints();
		gridBagConstraints7.gridx = 2;
		jPanel15.add(jLabel19, gridBagConstraints7);

		gridBagConstraints7 = new java.awt.GridBagConstraints();
		gridBagConstraints7.gridx = 3;
		gridBagConstraints7.fill = java.awt.GridBagConstraints.HORIZONTAL;
		jPanel15.add(personInfoCField, gridBagConstraints7);

		gridBagConstraints6 = new java.awt.GridBagConstraints();
		gridBagConstraints6.fill = java.awt.GridBagConstraints.HORIZONTAL;
		gridBagConstraints6.weightx = 10.0;
		jPanel12.add(jPanel15, gridBagConstraints6);

		personInfoButton.setFont(new java.awt.Font("Dialog", 1, 11));
		personInfoButton.setText("Ist korrekt!");
		gridBagConstraints6 = new java.awt.GridBagConstraints();
		gridBagConstraints6.gridx = 0;
		gridBagConstraints6.fill = java.awt.GridBagConstraints.HORIZONTAL;
		jPanel12.add(personInfoButton, gridBagConstraints6);

		gridBagConstraints2 = new java.awt.GridBagConstraints();
		gridBagConstraints2.gridx = 0;
		gridBagConstraints2.fill = java.awt.GridBagConstraints.HORIZONTAL;
		jPanel3.add(jPanel12, gridBagConstraints2);

		jPanel13.setLayout(new java.awt.GridBagLayout());
		java.awt.GridBagConstraints gridBagConstraints8;

		jPanel13.setBorder(
			new javax.swing.border.TitledBorder(
				"3. Schritt: Angaben unterschreiben"));
		jLabel10.setText("Passwort: ");
		gridBagConstraints8 = new java.awt.GridBagConstraints();
		jPanel13.add(jLabel10, gridBagConstraints8);

		personSignField.setMargin(new java.awt.Insets(2, 2, 2, 2));
		gridBagConstraints8 = new java.awt.GridBagConstraints();
		gridBagConstraints8.fill = java.awt.GridBagConstraints.HORIZONTAL;
		gridBagConstraints8.weightx = 10.0;
		jPanel13.add(personSignField, gridBagConstraints8);

		personSignButton.setFont(new java.awt.Font("Dialog", 1, 11));
		personSignButton.setText("Unterschreiben!");
		personSignButton.setMargin(new java.awt.Insets(2, 4, 2, 4));
		gridBagConstraints8 = new java.awt.GridBagConstraints();
		gridBagConstraints8.gridx = 0;
		gridBagConstraints8.gridy = 1;
		gridBagConstraints8.gridwidth = 2;
		gridBagConstraints8.fill = java.awt.GridBagConstraints.HORIZONTAL;
		jPanel13.add(personSignButton, gridBagConstraints8);

		gridBagConstraints2 = new java.awt.GridBagConstraints();
		gridBagConstraints2.gridx = 0;
		gridBagConstraints2.fill = java.awt.GridBagConstraints.HORIZONTAL;
		jPanel3.add(jPanel13, gridBagConstraints2);

		jPanel14.setLayout(new java.awt.GridBagLayout());
		java.awt.GridBagConstraints gridBagConstraints9;

		jPanel14.setBorder(
			new javax.swing.border.TitledBorder(
				"4. Schritt: Zertifikat abspeichern"));
		jLabel11.setText("Dateiname: ");
		gridBagConstraints9 = new java.awt.GridBagConstraints();
		gridBagConstraints9.fill = java.awt.GridBagConstraints.HORIZONTAL;
		jPanel14.add(jLabel11, gridBagConstraints9);

		personCertField.setMargin(new java.awt.Insets(2, 2, 2, 2));
		gridBagConstraints9 = new java.awt.GridBagConstraints();
		gridBagConstraints9.fill = java.awt.GridBagConstraints.HORIZONTAL;
		gridBagConstraints9.weightx = 10.0;
		jPanel14.add(personCertField, gridBagConstraints9);

		personCertButton.setText("Ausw\u00e4hlen");
		personCertButton.setMargin(new java.awt.Insets(2, 4, 2, 4));
		gridBagConstraints9 = new java.awt.GridBagConstraints();
		jPanel14.add(personCertButton, gridBagConstraints9);

		jLabel35.setText("Seriennummer: ");
		gridBagConstraints9 = new java.awt.GridBagConstraints();
		gridBagConstraints9.gridx = 0;
		gridBagConstraints9.fill = java.awt.GridBagConstraints.HORIZONTAL;
		jPanel14.add(jLabel35, gridBagConstraints9);

		personSerialField.setEditable(false);
		personSerialField.setMargin(new java.awt.Insets(2, 2, 2, 2));
		gridBagConstraints9 = new java.awt.GridBagConstraints();
		gridBagConstraints9.gridx = 1;
		gridBagConstraints9.gridwidth = 2;
		gridBagConstraints9.fill = java.awt.GridBagConstraints.HORIZONTAL;
		jPanel14.add(personSerialField, gridBagConstraints9);

		personSaveButton.setFont(new java.awt.Font("Dialog", 1, 11));
		personSaveButton.setText("Abspeichern");
		gridBagConstraints9 = new java.awt.GridBagConstraints();
		gridBagConstraints9.gridx = 0;
		gridBagConstraints9.gridwidth = 3;
		gridBagConstraints9.fill = java.awt.GridBagConstraints.HORIZONTAL;
		jPanel14.add(personSaveButton, gridBagConstraints9);

		gridBagConstraints2 = new java.awt.GridBagConstraints();
		gridBagConstraints2.gridx = 0;
		gridBagConstraints2.fill = java.awt.GridBagConstraints.HORIZONTAL;
		jPanel3.add(jPanel14, gridBagConstraints2);

		gridBagConstraints2 = new java.awt.GridBagConstraints();
		gridBagConstraints2.gridx = 0;
		gridBagConstraints2.weighty = 10.0;
		jPanel3.add(jPanel16, gridBagConstraints2);

		personMainButton.setText("Men\u00fc");
		gridBagConstraints2 = new java.awt.GridBagConstraints();
		gridBagConstraints2.gridx = 0;
		jPanel3.add(personMainButton, gridBagConstraints2);

		add(jPanel3, "person");

		jPanel4.setLayout(new java.awt.GridBagLayout());
		java.awt.GridBagConstraints gridBagConstraints10;

		jPanel17.setLayout(new java.awt.GridBagLayout());
		java.awt.GridBagConstraints gridBagConstraints11;

		jPanel17.setBorder(
			new javax.swing.border.TitledBorder(
				new javax.swing.border.EtchedBorder(),
				"1. Schritt: Public Key ausw\u00e4hlen"));
		roleDatabaseSelector.setSelected(true);
		roleDatabaseSelector.setText("Datenbank");
		jPanel18.add(roleDatabaseSelector);

		roleFileSelector.setText("Datei");
		jPanel18.add(roleFileSelector);

		roleStoreSelector.setText("Java Key Store");
		jPanel18.add(roleStoreSelector);

		gridBagConstraints11 = new java.awt.GridBagConstraints();
		gridBagConstraints11.gridwidth = 2;
		gridBagConstraints11.fill = java.awt.GridBagConstraints.HORIZONTAL;
		jPanel17.add(jPanel18, gridBagConstraints11);

		roleLoadPanel.setLayout(new java.awt.CardLayout());

		jPanel25.setLayout(new java.awt.GridBagLayout());
		java.awt.GridBagConstraints gridBagConstraints12;

		jLabel31.setText("Seriennummer: ");
		gridBagConstraints12 = new java.awt.GridBagConstraints();
		jPanel25.add(jLabel31, gridBagConstraints12);

		roleSerialField.setMargin(new java.awt.Insets(2, 2, 2, 2));
		gridBagConstraints12 = new java.awt.GridBagConstraints();
		gridBagConstraints12.fill = java.awt.GridBagConstraints.HORIZONTAL;
		gridBagConstraints12.weightx = 10.0;
		jPanel25.add(roleSerialField, gridBagConstraints12);

		gridBagConstraints12 = new java.awt.GridBagConstraints();
		gridBagConstraints12.gridx = 0;
		gridBagConstraints12.weighty = 10.0;
		jPanel25.add(jPanel26, gridBagConstraints12);

		roleLoadPanel.add(jPanel25, "db");

		jPanel20.setLayout(new java.awt.GridBagLayout());
		java.awt.GridBagConstraints gridBagConstraints13;

		jLabel21.setText("Dateiname: ");
		gridBagConstraints13 = new java.awt.GridBagConstraints();
		jPanel20.add(jLabel21, gridBagConstraints13);

		roleFileField.setMargin(new java.awt.Insets(2, 2, 2, 2));
		gridBagConstraints13 = new java.awt.GridBagConstraints();
		gridBagConstraints13.fill = java.awt.GridBagConstraints.HORIZONTAL;
		gridBagConstraints13.weightx = 10.0;
		jPanel20.add(roleFileField, gridBagConstraints13);

		roleFileButton.setText("Ausw\u00e4hlen");
		roleFileButton.setMargin(new java.awt.Insets(2, 4, 2, 4));
		gridBagConstraints13 = new java.awt.GridBagConstraints();
		jPanel20.add(roleFileButton, gridBagConstraints13);

		gridBagConstraints13 = new java.awt.GridBagConstraints();
		gridBagConstraints13.gridx = 0;
		gridBagConstraints13.fill = java.awt.GridBagConstraints.BOTH;
		gridBagConstraints13.weighty = 1.0;
		jPanel20.add(jPanel21, gridBagConstraints13);

		roleLoadPanel.add(jPanel20, "file");

		jPanel22.setLayout(new java.awt.GridBagLayout());
		java.awt.GridBagConstraints gridBagConstraints14;

		jLabel22.setText("Dateiname: ");
		gridBagConstraints14 = new java.awt.GridBagConstraints();
		jPanel22.add(jLabel22, gridBagConstraints14);

		roleStoreField.setMargin(new java.awt.Insets(2, 2, 2, 2));
		gridBagConstraints14 = new java.awt.GridBagConstraints();
		gridBagConstraints14.fill = java.awt.GridBagConstraints.HORIZONTAL;
		gridBagConstraints14.weightx = 10.0;
		jPanel22.add(roleStoreField, gridBagConstraints14);

		roleStoreButton.setText("Ausw\u00e4hlen");
		roleStoreButton.setMargin(new java.awt.Insets(2, 4, 2, 4));
		gridBagConstraints14 = new java.awt.GridBagConstraints();
		jPanel22.add(roleStoreButton, gridBagConstraints14);

		jLabel23.setText("Aliasname: ");
		gridBagConstraints14 = new java.awt.GridBagConstraints();
		gridBagConstraints14.gridx = 0;
		jPanel22.add(jLabel23, gridBagConstraints14);

		gridBagConstraints14 = new java.awt.GridBagConstraints();
		gridBagConstraints14.gridx = 1;
		gridBagConstraints14.fill = java.awt.GridBagConstraints.HORIZONTAL;
		jPanel22.add(roleAliasBox, gridBagConstraints14);

		roleAliasButton.setText("Erneuern");
		roleAliasButton.setMargin(new java.awt.Insets(2, 4, 2, 4));
		gridBagConstraints14 = new java.awt.GridBagConstraints();
		gridBagConstraints14.gridx = 2;
		gridBagConstraints14.fill = java.awt.GridBagConstraints.HORIZONTAL;
		jPanel22.add(roleAliasButton, gridBagConstraints14);

		roleLoadPanel.add(jPanel22, "jks");

		gridBagConstraints11 = new java.awt.GridBagConstraints();
		gridBagConstraints11.gridx = 0;
		gridBagConstraints11.gridwidth = 2;
		gridBagConstraints11.fill = java.awt.GridBagConstraints.BOTH;
		gridBagConstraints11.weightx = 10.0;
		jPanel17.add(roleLoadPanel, gridBagConstraints11);

		roleLoadButton.setFont(new java.awt.Font("Dialog", 1, 11));
		roleLoadButton.setText("Laden!");
		gridBagConstraints11 = new java.awt.GridBagConstraints();
		gridBagConstraints11.gridx = 1;
		gridBagConstraints11.gridy = 2;
		gridBagConstraints11.fill = java.awt.GridBagConstraints.HORIZONTAL;
		jPanel17.add(roleLoadButton, gridBagConstraints11);

		gridBagConstraints10 = new java.awt.GridBagConstraints();
		gridBagConstraints10.gridx = 0;
		gridBagConstraints10.fill = java.awt.GridBagConstraints.HORIZONTAL;
		gridBagConstraints10.weightx = 10.0;
		jPanel4.add(jPanel17, gridBagConstraints10);

		jPanel23.setLayout(new java.awt.GridBagLayout());
		java.awt.GridBagConstraints gridBagConstraints15;

		jPanel23.setBorder(
			new javax.swing.border.TitledBorder(
				new javax.swing.border.EtchedBorder(),
				"2. Schritt: Angaben pr\u00fcfen"));
		jPanel24.setLayout(new java.awt.GridBagLayout());
		java.awt.GridBagConstraints gridBagConstraints16;

		jLabel24.setText("Name (CN): ");
		jLabel24.setHorizontalAlignment(javax.swing.SwingConstants.LEFT);
		gridBagConstraints16 = new java.awt.GridBagConstraints();
		gridBagConstraints16.gridx = 0;
		gridBagConstraints16.fill = java.awt.GridBagConstraints.HORIZONTAL;
		jPanel24.add(jLabel24, gridBagConstraints16);

		gridBagConstraints16 = new java.awt.GridBagConstraints();
		gridBagConstraints16.gridx = 1;
		gridBagConstraints16.gridy = 0;
		gridBagConstraints16.fill = java.awt.GridBagConstraints.HORIZONTAL;
		gridBagConstraints16.weightx = 10.0;
		jPanel24.add(roleInfoCNField, gridBagConstraints16);

		jLabel25.setText("Abteilung (OU): ");
		jLabel25.setHorizontalAlignment(javax.swing.SwingConstants.LEFT);
		gridBagConstraints16 = new java.awt.GridBagConstraints();
		gridBagConstraints16.gridx = 0;
		gridBagConstraints16.fill = java.awt.GridBagConstraints.HORIZONTAL;
		jPanel24.add(jLabel25, gridBagConstraints16);

		gridBagConstraints16 = new java.awt.GridBagConstraints();
		gridBagConstraints16.gridx = 1;
		gridBagConstraints16.fill = java.awt.GridBagConstraints.HORIZONTAL;
		jPanel24.add(roleInfoOUField, gridBagConstraints16);

		jLabel26.setText("Organisation (O): ");
		jLabel26.setHorizontalAlignment(javax.swing.SwingConstants.LEFT);
		gridBagConstraints16 = new java.awt.GridBagConstraints();
		gridBagConstraints16.gridx = 0;
		gridBagConstraints16.fill = java.awt.GridBagConstraints.HORIZONTAL;
		jPanel24.add(jLabel26, gridBagConstraints16);

		gridBagConstraints16 = new java.awt.GridBagConstraints();
		gridBagConstraints16.gridx = 1;
		gridBagConstraints16.fill = java.awt.GridBagConstraints.HORIZONTAL;
		jPanel24.add(roleInfoOField, gridBagConstraints16);

		jLabel27.setText("Fingerprint:");
		gridBagConstraints16 = new java.awt.GridBagConstraints();
		gridBagConstraints16.gridx = 0;
		gridBagConstraints16.fill = java.awt.GridBagConstraints.HORIZONTAL;
		jPanel24.add(jLabel27, gridBagConstraints16);

		roleInfoHashField.setEditable(false);
		gridBagConstraints16 = new java.awt.GridBagConstraints();
		gridBagConstraints16.gridx = 1;
		gridBagConstraints16.gridy = 3;
		gridBagConstraints16.gridwidth = 3;
		gridBagConstraints16.fill = java.awt.GridBagConstraints.HORIZONTAL;
		jPanel24.add(roleInfoHashField, gridBagConstraints16);

		jLabel28.setText(" Stadt (L): ");
		gridBagConstraints16 = new java.awt.GridBagConstraints();
		gridBagConstraints16.gridx = 2;
		gridBagConstraints16.gridy = 0;
		gridBagConstraints16.fill = java.awt.GridBagConstraints.HORIZONTAL;
		jPanel24.add(jLabel28, gridBagConstraints16);

		gridBagConstraints16 = new java.awt.GridBagConstraints();
		gridBagConstraints16.gridx = 3;
		gridBagConstraints16.gridy = 0;
		gridBagConstraints16.fill = java.awt.GridBagConstraints.HORIZONTAL;
		gridBagConstraints16.weightx = 10.0;
		jPanel24.add(roleInfoLField, gridBagConstraints16);

		jLabel29.setText(" Bundesland (ST): ");
		gridBagConstraints16 = new java.awt.GridBagConstraints();
		gridBagConstraints16.gridx = 2;
		gridBagConstraints16.fill = java.awt.GridBagConstraints.HORIZONTAL;
		jPanel24.add(jLabel29, gridBagConstraints16);

		gridBagConstraints16 = new java.awt.GridBagConstraints();
		gridBagConstraints16.gridx = 3;
		gridBagConstraints16.fill = java.awt.GridBagConstraints.HORIZONTAL;
		jPanel24.add(roleInfoSTField, gridBagConstraints16);

		jLabel30.setText(" L\u00e4nderk\u00fcrzel (C): ");
		gridBagConstraints16 = new java.awt.GridBagConstraints();
		gridBagConstraints16.gridx = 2;
		jPanel24.add(jLabel30, gridBagConstraints16);

		gridBagConstraints16 = new java.awt.GridBagConstraints();
		gridBagConstraints16.gridx = 3;
		gridBagConstraints16.fill = java.awt.GridBagConstraints.HORIZONTAL;
		jPanel24.add(roleInfoCField, gridBagConstraints16);

		gridBagConstraints15 = new java.awt.GridBagConstraints();
		gridBagConstraints15.fill = java.awt.GridBagConstraints.HORIZONTAL;
		gridBagConstraints15.weightx = 10.0;
		jPanel23.add(jPanel24, gridBagConstraints15);

		roleInfoButton.setFont(new java.awt.Font("Dialog", 1, 11));
		roleInfoButton.setText("Ist korrekt!");
		gridBagConstraints15 = new java.awt.GridBagConstraints();
		gridBagConstraints15.gridx = 0;
		gridBagConstraints15.fill = java.awt.GridBagConstraints.HORIZONTAL;
		jPanel23.add(roleInfoButton, gridBagConstraints15);

		gridBagConstraints10 = new java.awt.GridBagConstraints();
		gridBagConstraints10.gridx = 0;
		gridBagConstraints10.fill = java.awt.GridBagConstraints.HORIZONTAL;
		jPanel4.add(jPanel23, gridBagConstraints10);

		jPanel27.setLayout(new java.awt.GridBagLayout());
		java.awt.GridBagConstraints gridBagConstraints17;

		jPanel27.setBorder(
			new javax.swing.border.TitledBorder(
				new javax.swing.border.EtchedBorder(),
				"3. Schritt: Angaben unterschreiben"));
		jLabel32.setText("Passwort: ");
		gridBagConstraints17 = new java.awt.GridBagConstraints();
		jPanel27.add(jLabel32, gridBagConstraints17);

		roleSignField.setMargin(new java.awt.Insets(2, 2, 2, 2));
		gridBagConstraints17 = new java.awt.GridBagConstraints();
		gridBagConstraints17.fill = java.awt.GridBagConstraints.HORIZONTAL;
		gridBagConstraints17.weightx = 10.0;
		jPanel27.add(roleSignField, gridBagConstraints17);

		jLabel34.setText("Rolle:");
		gridBagConstraints17 = new java.awt.GridBagConstraints();
		gridBagConstraints17.gridx = 0;
		gridBagConstraints17.fill = java.awt.GridBagConstraints.HORIZONTAL;
		jPanel27.add(jLabel34, gridBagConstraints17);

		roleRoleField.setMargin(new java.awt.Insets(2, 2, 2, 2));
		gridBagConstraints17 = new java.awt.GridBagConstraints();
		gridBagConstraints17.gridx = 1;
		gridBagConstraints17.fill = java.awt.GridBagConstraints.HORIZONTAL;
		gridBagConstraints17.weightx = 10.0;
		jPanel27.add(roleRoleField, gridBagConstraints17);

		roleSignButton.setFont(new java.awt.Font("Dialog", 1, 11));
		roleSignButton.setText("Unterschreiben!");
		roleSignButton.setMargin(new java.awt.Insets(2, 4, 2, 4));
		gridBagConstraints17 = new java.awt.GridBagConstraints();
		gridBagConstraints17.gridx = 0;
		gridBagConstraints17.gridwidth = 2;
		gridBagConstraints17.fill = java.awt.GridBagConstraints.HORIZONTAL;
		jPanel27.add(roleSignButton, gridBagConstraints17);

		gridBagConstraints10 = new java.awt.GridBagConstraints();
		gridBagConstraints10.gridx = 0;
		gridBagConstraints10.fill = java.awt.GridBagConstraints.HORIZONTAL;
		jPanel4.add(jPanel27, gridBagConstraints10);

		jPanel28.setLayout(new java.awt.GridBagLayout());
		java.awt.GridBagConstraints gridBagConstraints18;

		jPanel28.setBorder(
			new javax.swing.border.TitledBorder(
				new javax.swing.border.EtchedBorder(),
				"4. Schritt: Zertifikat abspeichern"));
		jLabel33.setText("Dateiname: ");
		gridBagConstraints18 = new java.awt.GridBagConstraints();
		jPanel28.add(jLabel33, gridBagConstraints18);

		roleCertField.setMargin(new java.awt.Insets(2, 2, 2, 2));
		gridBagConstraints18 = new java.awt.GridBagConstraints();
		gridBagConstraints18.fill = java.awt.GridBagConstraints.HORIZONTAL;
		gridBagConstraints18.weightx = 10.0;
		jPanel28.add(roleCertField, gridBagConstraints18);

		roleCertButton.setText("Ausw\u00e4hlen");
		roleCertButton.setMargin(new java.awt.Insets(2, 4, 2, 4));
		gridBagConstraints18 = new java.awt.GridBagConstraints();
		jPanel28.add(roleCertButton, gridBagConstraints18);

		roleSaveButton.setFont(new java.awt.Font("Dialog", 1, 11));
		roleSaveButton.setText("Abspeichern");
		gridBagConstraints18 = new java.awt.GridBagConstraints();
		gridBagConstraints18.gridx = 0;
		gridBagConstraints18.gridwidth = 3;
		gridBagConstraints18.fill = java.awt.GridBagConstraints.HORIZONTAL;
		jPanel28.add(roleSaveButton, gridBagConstraints18);

		gridBagConstraints10 = new java.awt.GridBagConstraints();
		gridBagConstraints10.gridx = 0;
		gridBagConstraints10.fill = java.awt.GridBagConstraints.HORIZONTAL;
		jPanel4.add(jPanel28, gridBagConstraints10);

		gridBagConstraints10 = new java.awt.GridBagConstraints();
		gridBagConstraints10.gridx = 0;
		gridBagConstraints10.weighty = 10.0;
		jPanel4.add(jPanel29, gridBagConstraints10);

		roleMainButton.setText("Men\u00fc");
		gridBagConstraints10 = new java.awt.GridBagConstraints();
		gridBagConstraints10.gridx = 0;
		jPanel4.add(roleMainButton, gridBagConstraints10);

		add(jPanel4, "role");

		jPanel5.setLayout(new java.awt.GridBagLayout());
		java.awt.GridBagConstraints gridBagConstraints19;

		jPanel30.setLayout(new java.awt.GridBagLayout());
		java.awt.GridBagConstraints gridBagConstraints20;

		jPanel30.setBorder(
			new javax.swing.border.TitledBorder(
				new javax.swing.border.EtchedBorder(),
				"1. Schritt: Public Key ausw\u00e4hlen"));
		pseudonymDatabaseSelector.setSelected(true);
		pseudonymDatabaseSelector.setText("Datenbank");
		jPanel31.add(pseudonymDatabaseSelector);

		pseudonymFileSelector.setText("Datei");
		jPanel31.add(pseudonymFileSelector);

		pseudonymStoreSelector.setText("Java Key Store");
		jPanel31.add(pseudonymStoreSelector);

		gridBagConstraints20 = new java.awt.GridBagConstraints();
		gridBagConstraints20.gridwidth = 2;
		gridBagConstraints20.fill = java.awt.GridBagConstraints.HORIZONTAL;
		jPanel30.add(jPanel31, gridBagConstraints20);

		pseudonymLoadPanel.setLayout(new java.awt.CardLayout());

		jPanel33.setLayout(new java.awt.GridBagLayout());
		java.awt.GridBagConstraints gridBagConstraints21;

		jLabel36.setText("Seriennummer: ");
		gridBagConstraints21 = new java.awt.GridBagConstraints();
		jPanel33.add(jLabel36, gridBagConstraints21);

		pseudonymSerialField.setMargin(new java.awt.Insets(2, 2, 2, 2));
		gridBagConstraints21 = new java.awt.GridBagConstraints();
		gridBagConstraints21.fill = java.awt.GridBagConstraints.HORIZONTAL;
		gridBagConstraints21.weightx = 10.0;
		jPanel33.add(pseudonymSerialField, gridBagConstraints21);

		gridBagConstraints21 = new java.awt.GridBagConstraints();
		gridBagConstraints21.gridx = 0;
		gridBagConstraints21.weighty = 10.0;
		jPanel33.add(jPanel34, gridBagConstraints21);

		pseudonymLoadPanel.add(jPanel33, "db");

		jPanel35.setLayout(new java.awt.GridBagLayout());
		java.awt.GridBagConstraints gridBagConstraints22;

		jLabel37.setText("Dateiname: ");
		gridBagConstraints22 = new java.awt.GridBagConstraints();
		jPanel35.add(jLabel37, gridBagConstraints22);

		pseudonymFileField.setMargin(new java.awt.Insets(2, 2, 2, 2));
		gridBagConstraints22 = new java.awt.GridBagConstraints();
		gridBagConstraints22.fill = java.awt.GridBagConstraints.HORIZONTAL;
		gridBagConstraints22.weightx = 10.0;
		jPanel35.add(pseudonymFileField, gridBagConstraints22);

		pseudonymFileButton.setText("Ausw\u00e4hlen");
		pseudonymFileButton.setMargin(new java.awt.Insets(2, 4, 2, 4));
		gridBagConstraints22 = new java.awt.GridBagConstraints();
		jPanel35.add(pseudonymFileButton, gridBagConstraints22);

		gridBagConstraints22 = new java.awt.GridBagConstraints();
		gridBagConstraints22.gridx = 0;
		gridBagConstraints22.fill = java.awt.GridBagConstraints.BOTH;
		gridBagConstraints22.weighty = 1.0;
		jPanel35.add(jPanel36, gridBagConstraints22);

		pseudonymLoadPanel.add(jPanel35, "file");

		jPanel37.setLayout(new java.awt.GridBagLayout());
		java.awt.GridBagConstraints gridBagConstraints23;

		jLabel38.setText("Dateiname: ");
		gridBagConstraints23 = new java.awt.GridBagConstraints();
		jPanel37.add(jLabel38, gridBagConstraints23);

		pseudonymStoreField.setMargin(new java.awt.Insets(2, 2, 2, 2));
		gridBagConstraints23 = new java.awt.GridBagConstraints();
		gridBagConstraints23.fill = java.awt.GridBagConstraints.HORIZONTAL;
		gridBagConstraints23.weightx = 10.0;
		jPanel37.add(pseudonymStoreField, gridBagConstraints23);

		pseudonymStoreButton.setText("Ausw\u00e4hlen");
		pseudonymStoreButton.setMargin(new java.awt.Insets(2, 4, 2, 4));
		gridBagConstraints23 = new java.awt.GridBagConstraints();
		jPanel37.add(pseudonymStoreButton, gridBagConstraints23);

		jLabel39.setText("Aliasname: ");
		gridBagConstraints23 = new java.awt.GridBagConstraints();
		gridBagConstraints23.gridx = 0;
		jPanel37.add(jLabel39, gridBagConstraints23);

		gridBagConstraints23 = new java.awt.GridBagConstraints();
		gridBagConstraints23.gridx = 1;
		gridBagConstraints23.fill = java.awt.GridBagConstraints.HORIZONTAL;
		jPanel37.add(pseudonymAliasBox, gridBagConstraints23);

		pseudonymAliasButton.setText("Erneuern");
		pseudonymAliasButton.setMargin(new java.awt.Insets(2, 4, 2, 4));
		gridBagConstraints23 = new java.awt.GridBagConstraints();
		gridBagConstraints23.gridx = 2;
		gridBagConstraints23.fill = java.awt.GridBagConstraints.HORIZONTAL;
		jPanel37.add(pseudonymAliasButton, gridBagConstraints23);

		pseudonymLoadPanel.add(jPanel37, "jks");

		gridBagConstraints20 = new java.awt.GridBagConstraints();
		gridBagConstraints20.gridx = 0;
		gridBagConstraints20.gridwidth = 2;
		gridBagConstraints20.fill = java.awt.GridBagConstraints.BOTH;
		gridBagConstraints20.weightx = 10.0;
		jPanel30.add(pseudonymLoadPanel, gridBagConstraints20);

		pseudonymLoadButton.setFont(new java.awt.Font("Dialog", 1, 11));
		pseudonymLoadButton.setText("Laden!");
		gridBagConstraints20 = new java.awt.GridBagConstraints();
		gridBagConstraints20.gridx = 1;
		gridBagConstraints20.gridy = 2;
		gridBagConstraints20.fill = java.awt.GridBagConstraints.HORIZONTAL;
		jPanel30.add(pseudonymLoadButton, gridBagConstraints20);

		gridBagConstraints19 = new java.awt.GridBagConstraints();
		gridBagConstraints19.gridx = 0;
		gridBagConstraints19.fill = java.awt.GridBagConstraints.HORIZONTAL;
		gridBagConstraints19.weightx = 10.0;
		jPanel5.add(jPanel30, gridBagConstraints19);

		jPanel38.setLayout(new java.awt.GridBagLayout());
		java.awt.GridBagConstraints gridBagConstraints24;

		jPanel38.setBorder(
			new javax.swing.border.TitledBorder(
				new javax.swing.border.EtchedBorder(),
				"2. Schritt: Angaben pr\u00fcfen"));
		jPanel39.setLayout(new java.awt.GridBagLayout());
		java.awt.GridBagConstraints gridBagConstraints25;

		jLabel40.setText("Name (CN): ");
		jLabel40.setHorizontalAlignment(javax.swing.SwingConstants.LEFT);
		gridBagConstraints25 = new java.awt.GridBagConstraints();
		gridBagConstraints25.gridx = 0;
		gridBagConstraints25.fill = java.awt.GridBagConstraints.HORIZONTAL;
		jPanel39.add(jLabel40, gridBagConstraints25);

		gridBagConstraints25 = new java.awt.GridBagConstraints();
		gridBagConstraints25.gridx = 1;
		gridBagConstraints25.gridy = 0;
		gridBagConstraints25.fill = java.awt.GridBagConstraints.HORIZONTAL;
		gridBagConstraints25.weightx = 10.0;
		jPanel39.add(pseudonymInfoCNField, gridBagConstraints25);

		jLabel41.setText("Abteilung (OU): ");
		jLabel41.setHorizontalAlignment(javax.swing.SwingConstants.LEFT);
		gridBagConstraints25 = new java.awt.GridBagConstraints();
		gridBagConstraints25.gridx = 0;
		gridBagConstraints25.fill = java.awt.GridBagConstraints.HORIZONTAL;
		jPanel39.add(jLabel41, gridBagConstraints25);

		gridBagConstraints25 = new java.awt.GridBagConstraints();
		gridBagConstraints25.gridx = 1;
		gridBagConstraints25.fill = java.awt.GridBagConstraints.HORIZONTAL;
		jPanel39.add(pseudonymInfoOUField, gridBagConstraints25);

		jLabel42.setText("Organisation (O): ");
		jLabel42.setHorizontalAlignment(javax.swing.SwingConstants.LEFT);
		gridBagConstraints25 = new java.awt.GridBagConstraints();
		gridBagConstraints25.gridx = 0;
		gridBagConstraints25.fill = java.awt.GridBagConstraints.HORIZONTAL;
		jPanel39.add(jLabel42, gridBagConstraints25);

		gridBagConstraints25 = new java.awt.GridBagConstraints();
		gridBagConstraints25.gridx = 1;
		gridBagConstraints25.fill = java.awt.GridBagConstraints.HORIZONTAL;
		jPanel39.add(pseudonymInfoOField, gridBagConstraints25);

		jLabel43.setText("Fingerprint:");
		gridBagConstraints25 = new java.awt.GridBagConstraints();
		gridBagConstraints25.gridx = 0;
		gridBagConstraints25.fill = java.awt.GridBagConstraints.HORIZONTAL;
		jPanel39.add(jLabel43, gridBagConstraints25);

		pseudonymInfoHashField.setEditable(false);
		gridBagConstraints25 = new java.awt.GridBagConstraints();
		gridBagConstraints25.gridx = 1;
		gridBagConstraints25.gridy = 3;
		gridBagConstraints25.gridwidth = 3;
		gridBagConstraints25.fill = java.awt.GridBagConstraints.HORIZONTAL;
		jPanel39.add(pseudonymInfoHashField, gridBagConstraints25);

		jLabel44.setText(" Stadt (L): ");
		gridBagConstraints25 = new java.awt.GridBagConstraints();
		gridBagConstraints25.gridx = 2;
		gridBagConstraints25.gridy = 0;
		gridBagConstraints25.fill = java.awt.GridBagConstraints.HORIZONTAL;
		jPanel39.add(jLabel44, gridBagConstraints25);

		gridBagConstraints25 = new java.awt.GridBagConstraints();
		gridBagConstraints25.gridx = 3;
		gridBagConstraints25.gridy = 0;
		gridBagConstraints25.fill = java.awt.GridBagConstraints.HORIZONTAL;
		gridBagConstraints25.weightx = 10.0;
		jPanel39.add(pseudonymInfoLField, gridBagConstraints25);

		jLabel45.setText(" Bundesland (ST): ");
		gridBagConstraints25 = new java.awt.GridBagConstraints();
		gridBagConstraints25.gridx = 2;
		gridBagConstraints25.fill = java.awt.GridBagConstraints.HORIZONTAL;
		jPanel39.add(jLabel45, gridBagConstraints25);

		gridBagConstraints25 = new java.awt.GridBagConstraints();
		gridBagConstraints25.gridx = 3;
		gridBagConstraints25.fill = java.awt.GridBagConstraints.HORIZONTAL;
		jPanel39.add(pseudonymInfoSTField, gridBagConstraints25);

		jLabel46.setText(" L\u00e4nderk\u00fcrzel (C): ");
		gridBagConstraints25 = new java.awt.GridBagConstraints();
		gridBagConstraints25.gridx = 2;
		jPanel39.add(jLabel46, gridBagConstraints25);

		gridBagConstraints25 = new java.awt.GridBagConstraints();
		gridBagConstraints25.gridx = 3;
		gridBagConstraints25.fill = java.awt.GridBagConstraints.HORIZONTAL;
		jPanel39.add(pseudonymInfoCField, gridBagConstraints25);

		gridBagConstraints24 = new java.awt.GridBagConstraints();
		gridBagConstraints24.fill = java.awt.GridBagConstraints.HORIZONTAL;
		gridBagConstraints24.weightx = 10.0;
		jPanel38.add(jPanel39, gridBagConstraints24);

		pseudonymInfoButton.setFont(new java.awt.Font("Dialog", 1, 11));
		pseudonymInfoButton.setText("Ist korrekt!");
		gridBagConstraints24 = new java.awt.GridBagConstraints();
		gridBagConstraints24.gridx = 0;
		gridBagConstraints24.fill = java.awt.GridBagConstraints.HORIZONTAL;
		jPanel38.add(pseudonymInfoButton, gridBagConstraints24);

		gridBagConstraints19 = new java.awt.GridBagConstraints();
		gridBagConstraints19.gridx = 0;
		gridBagConstraints19.fill = java.awt.GridBagConstraints.HORIZONTAL;
		jPanel5.add(jPanel38, gridBagConstraints19);

		jPanel40.setLayout(new java.awt.GridBagLayout());
		java.awt.GridBagConstraints gridBagConstraints26;

		jPanel40.setBorder(
			new javax.swing.border.TitledBorder(
				new javax.swing.border.EtchedBorder(),
				"3. Schritt: Angaben unterschreiben"));
		jLabel47.setText("Passwort: ");
		gridBagConstraints26 = new java.awt.GridBagConstraints();
		jPanel40.add(jLabel47, gridBagConstraints26);

		pseudonymSignField.setMargin(new java.awt.Insets(2, 2, 2, 2));
		gridBagConstraints26 = new java.awt.GridBagConstraints();
		gridBagConstraints26.fill = java.awt.GridBagConstraints.HORIZONTAL;
		gridBagConstraints26.weightx = 10.0;
		jPanel40.add(pseudonymSignField, gridBagConstraints26);

		pseudonymSignButton.setFont(new java.awt.Font("Dialog", 1, 11));
		pseudonymSignButton.setText("Unterschreiben!");
		pseudonymSignButton.setMargin(new java.awt.Insets(2, 4, 2, 4));
		gridBagConstraints26 = new java.awt.GridBagConstraints();
		gridBagConstraints26.gridx = 0;
		gridBagConstraints26.gridy = 1;
		gridBagConstraints26.gridwidth = 2;
		gridBagConstraints26.fill = java.awt.GridBagConstraints.HORIZONTAL;
		jPanel40.add(pseudonymSignButton, gridBagConstraints26);

		gridBagConstraints19 = new java.awt.GridBagConstraints();
		gridBagConstraints19.gridx = 0;
		gridBagConstraints19.fill = java.awt.GridBagConstraints.HORIZONTAL;
		jPanel5.add(jPanel40, gridBagConstraints19);

		jPanel41.setLayout(new java.awt.GridBagLayout());
		java.awt.GridBagConstraints gridBagConstraints27;

		jPanel41.setBorder(
			new javax.swing.border.TitledBorder(
				new javax.swing.border.EtchedBorder(),
				"4. Schritt: Zertifikat abspeichern"));
		jLabel48.setText("Dateiname: ");
		gridBagConstraints27 = new java.awt.GridBagConstraints();
		jPanel41.add(jLabel48, gridBagConstraints27);

		pseudonymCertField.setMargin(new java.awt.Insets(2, 2, 2, 2));
		gridBagConstraints27 = new java.awt.GridBagConstraints();
		gridBagConstraints27.fill = java.awt.GridBagConstraints.HORIZONTAL;
		gridBagConstraints27.weightx = 10.0;
		jPanel41.add(pseudonymCertField, gridBagConstraints27);

		pseudonymCertButton.setText("Ausw\u00e4hlen");
		pseudonymCertButton.setMargin(new java.awt.Insets(2, 4, 2, 4));
		gridBagConstraints27 = new java.awt.GridBagConstraints();
		jPanel41.add(pseudonymCertButton, gridBagConstraints27);

		pseudonymSaveButton.setFont(new java.awt.Font("Dialog", 1, 11));
		pseudonymSaveButton.setText("Abspeichern");
		gridBagConstraints27 = new java.awt.GridBagConstraints();
		gridBagConstraints27.gridx = 0;
		gridBagConstraints27.gridwidth = 3;
		gridBagConstraints27.fill = java.awt.GridBagConstraints.HORIZONTAL;
		jPanel41.add(pseudonymSaveButton, gridBagConstraints27);

		gridBagConstraints19 = new java.awt.GridBagConstraints();
		gridBagConstraints19.gridx = 0;
		gridBagConstraints19.fill = java.awt.GridBagConstraints.HORIZONTAL;
		jPanel5.add(jPanel41, gridBagConstraints19);

		gridBagConstraints19 = new java.awt.GridBagConstraints();
		gridBagConstraints19.gridx = 0;
		gridBagConstraints19.weighty = 10.0;
		jPanel5.add(jPanel42, gridBagConstraints19);

		pseudonymMainButton.setText("Men\u00fc");
		gridBagConstraints19 = new java.awt.GridBagConstraints();
		gridBagConstraints19.gridx = 0;
		jPanel5.add(pseudonymMainButton, gridBagConstraints19);

		add(jPanel5, "pseudonym");

		jLabel1.setText(
			"Das ist ein unsichtbares, aber breites Label, um eine Mindestbreite zu erzwingen.");
		add(jLabel1, "jLabel1");

	} //GEN-END:initComponents

	public void actionPerformed(java.awt.event.ActionEvent p1) {
		Object src = p1.getSource();
		if (src == settingsItem) {
			if (psp == null) {
				psp = new PKISettingsDialog(settings);
			}
			psp.start();
		}

		if (src == mainPersonButton)
			 ((java.awt.CardLayout)getLayout()).show(this, "person");
		if (src == mainRoleButton)
			 ((java.awt.CardLayout)getLayout()).show(this, "role");
		if (src == mainPseudonymButton)
			 ((java.awt.CardLayout)getLayout()).show(this, "pseudonym");
		if ((src == mainExitButton) || (src == stopPKIItem)) {
			Main.stop();
		}
		if (src == personMainButton)
			 ((java.awt.CardLayout)getLayout()).show(this, "main");
		if (src == roleMainButton)
			 ((java.awt.CardLayout)getLayout()).show(this, "main");
		if (src == pseudonymMainButton)
			 ((java.awt.CardLayout)getLayout()).show(this, "main");
		if (src == personLoadButton) {
			personModel = new PKIModel();
			if (personFileSelector.isSelected()) {
				String file = personFileField.getText();
				if (file.length() > 0) {
					personModel.identity = PKIUtils.getFileCertificate(file);
				} else {
					String[] msg =
						{
							"Sie haben keinen Dateinamen angegeben.",
							"Laden nicht mglich." };
					javax.swing.JOptionPane.showMessageDialog(
						this,
						msg,
						"Fehler",
						javax.swing.JOptionPane.ERROR_MESSAGE);
				}
			}
			if (personStoreSelector.isSelected()) {
				String file = personStoreField.getText();
				String alias = (String)personAliasBox.getSelectedItem();
				if (file.length() > 0) {
					if (alias != null) {
						personModel.identity =
							PKIUtils.getStoreCertificate(file, alias);
					} else {
						String[] msg =
							{
								"Sie haben kein Alias ausgewhlt.",
								"Bitte drcken sie Erneuern und whlen eines aus." };
						javax.swing.JOptionPane.showMessageDialog(this, msg);
					}
				} else {
					String[] msg =
						{
							"Sie haben keinen Dateinamen angegeben.",
							"Laden nicht mglich." };
					javax.swing.JOptionPane.showMessageDialog(
						this,
						msg,
						"Fehler",
						javax.swing.JOptionPane.ERROR_MESSAGE);
				}
			}
			if (personModel.identity != null) {
				java.util.Hashtable p = PKIUtils.decrypt(personModel.identity);
				personInfoCNField.setText((String)p.get("CN"));
				personInfoOUField.setText((String)p.get("OU"));
				personInfoOField.setText((String)p.get("O"));
				personInfoLField.setText((String)p.get("L"));
				personInfoSTField.setText((String)p.get("ST"));
				personInfoCField.setText((String)p.get("C"));
			}
		}
		if (src == personAliasButton) {
			String file = personStoreField.getText();
			if (file.length() > 0) {
				String[] alias = PKIUtils.getAliasFromStore(file);
				while (personAliasBox.getItemCount() > 0) {
					personAliasBox.removeItem(personAliasBox.getItemAt(0));
				}
				if (alias.length > 0) {
					for (int i = 0; i < alias.length; i++) {
						personAliasBox.addItem(alias[i]);
					}
				} else {
					String[] msg =
						{
							"Es wurden keine Aliase gefunden.",
							"Prfen Sie bitte die Richtigkeit des Dateinamens." };
					javax.swing.JOptionPane.showMessageDialog(this, msg);
				}
			} else {
				String[] msg =
					{
						"Sie haben keinen Dateinamen angegeben.",
						"Laden nicht mglich." };
				javax.swing.JOptionPane.showMessageDialog(
					this,
					msg,
					"Fehler",
					javax.swing.JOptionPane.ERROR_MESSAGE);
			}
		}
		if (src == personInfoButton) {
			if (personModel.identity != null) {
				personModel.info = new java.util.Properties();
				personModel.info.setProperty("CN", personInfoCNField.getText());
				personModel.info.setProperty("C", personInfoCField.getText());
				personModel.info.setProperty("OU", personInfoOUField.getText());
				personModel.info.setProperty("O", personInfoOField.getText());
				personModel.info.setProperty("ST", personInfoSTField.getText());
				personModel.info.setProperty("L", personInfoLField.getText());
			} else {
				String[] msg =
					{
						"Sie haben noch kein Zertifikat geladen.",
						"berprfung nicht mglich." };
				javax.swing.JOptionPane.showMessageDialog(this, msg);
			}
		}
		if (src == personSignButton) {
			if (personModel.info != null) {
				personModel.certificate =
					certifier.createPersonCertificate(
						personModel.identity.getPublicKey(),
						personModel.info,
						personSignField.getPassword());
				personSerialField.setText(
					personModel.certificate.getSerialNumber().toString());
				if (personModel.certificate == null) {
					String[] msg =
						{
							"Es wurde kein Zertifikat erzeugt.",
							"Haben sie das korrekte Passwort angegeben?" };
					javax.swing.JOptionPane.showMessageDialog(
						this,
						msg,
						"Fehler",
						javax.swing.JOptionPane.ERROR_MESSAGE);
					personSignField.requestFocus();
				}
			} else {
				String[] msg =
					{
						"Sie haben die Korrektheit der Daten noch nicht besttigt.",
						"Signieren nicht mglich." };
				javax.swing.JOptionPane.showMessageDialog(this, msg);
				personInfoButton.requestFocus();
			}
		}
		if (src == personSaveButton) {
			String filename = personCertField.getText();
			if (personModel.certificate != null) {
				if (filename.length() > 0) {
					PKIUtils.saveCertificate(filename, personModel.certificate);
				} else {
					String[] msg =
						{
							"Sie haben noch keinen Dateinamen angegeben.",
							"Speichern nicht mglich." };
					javax.swing.JOptionPane.showMessageDialog(this, msg);
				}
			} else {
				String[] msg =
					{
						"Sie haben noch kein gltiges Zertifikat erzeugt.",
						"Speichern nicht mglich." };
				javax.swing.JOptionPane.showMessageDialog(this, msg);
			}
		}

	}

	public void itemStateChanged(java.awt.event.ItemEvent p1) {
		Object src = p1.getSource();
		if (src == roleStoreSelector
			|| src == roleFileSelector
			|| src == roleDatabaseSelector) {
			if (roleStoreSelector.isSelected())
				((java.awt.CardLayout)roleLoadPanel.getLayout()).show(
					roleLoadPanel,
					"jks");
			if (roleFileSelector.isSelected())
				((java.awt.CardLayout)roleLoadPanel.getLayout()).show(
					roleLoadPanel,
					"file");
			if (roleDatabaseSelector.isSelected())
				((java.awt.CardLayout)roleLoadPanel.getLayout()).show(
					roleLoadPanel,
					"db");
		}
		if (src == pseudonymStoreSelector
			|| src == pseudonymFileSelector
			|| src == pseudonymDatabaseSelector) {
			if (pseudonymStoreSelector.isSelected())
				((java.awt.CardLayout)pseudonymLoadPanel.getLayout()).show(
					pseudonymLoadPanel,
					"jks");
			if (pseudonymFileSelector.isSelected())
				((java.awt.CardLayout)pseudonymLoadPanel.getLayout()).show(
					pseudonymLoadPanel,
					"file");
			if (pseudonymDatabaseSelector.isSelected())
				((java.awt.CardLayout)pseudonymLoadPanel.getLayout()).show(
					pseudonymLoadPanel,
					"db");
		}
		if (src == personStoreSelector || src == personFileSelector) {
			if (personStoreSelector.isSelected())
				((java.awt.CardLayout)personLoadPanel.getLayout()).show(
					personLoadPanel,
					"jks");
			if (personFileSelector.isSelected())
				((java.awt.CardLayout)personLoadPanel.getLayout()).show(
					personLoadPanel,
					"file");
		}
	}

	// WindowAdapter for handling window events
	class myWindowAdapter extends WindowAdapter {
		public void windowClosing(WindowEvent e) {
			Main.stop();
		}
	}
	private WindowAdapter windowAdapter = new myWindowAdapter();

	// Variables declaration - do not modify//GEN-BEGIN:variables
	private javax.swing.JPanel jPanel2;
	private javax.swing.JLabel jLabel2;
	private javax.swing.JButton mainPersonButton;
	private javax.swing.JButton mainRoleButton;
	private javax.swing.JButton mainPseudonymButton;
	private javax.swing.JButton mainExitButton;
	private javax.swing.JPanel jPanel3;
	private javax.swing.JPanel jPanel6;
	private javax.swing.JPanel jPanel7;
	private javax.swing.JRadioButton personFileSelector;
	private javax.swing.JRadioButton personStoreSelector;
	private javax.swing.JPanel personLoadPanel;
	private javax.swing.JPanel jPanel9;
	private javax.swing.JLabel jLabel3;
	private javax.swing.JTextField personFileField;
	private javax.swing.JButton personFileButton;
	private javax.swing.JPanel jPanel11;
	private javax.swing.JPanel jPanel10;
	private javax.swing.JLabel jLabel4;
	private javax.swing.JTextField personStoreField;
	private javax.swing.JButton personStoreButton;
	private javax.swing.JLabel jLabel5;
	private javax.swing.JComboBox personAliasBox;
	private javax.swing.JButton personAliasButton;
	private javax.swing.JButton personLoadButton;
	private javax.swing.JPanel jPanel12;
	private javax.swing.JPanel jPanel15;
	private javax.swing.JLabel jLabel12;
	private javax.swing.JTextField personInfoCNField;
	private javax.swing.JLabel jLabel13;
	private javax.swing.JTextField personInfoOUField;
	private javax.swing.JLabel jLabel14;
	private javax.swing.JTextField personInfoOField;
	private javax.swing.JLabel jLabel15;
	private javax.swing.JTextField personInfoHashField;
	private javax.swing.JLabel jLabel17;
	private javax.swing.JTextField personInfoLField;
	private javax.swing.JLabel jLabel18;
	private javax.swing.JTextField personInfoSTField;
	private javax.swing.JLabel jLabel19;
	private javax.swing.JTextField personInfoCField;
	private javax.swing.JButton personInfoButton;
	private javax.swing.JPanel jPanel13;
	private javax.swing.JLabel jLabel10;
	private javax.swing.JPasswordField personSignField;
	private javax.swing.JButton personSignButton;
	private javax.swing.JPanel jPanel14;
	private javax.swing.JLabel jLabel11;
	private javax.swing.JTextField personCertField;
	private javax.swing.JButton personCertButton;
	private javax.swing.JLabel jLabel35;
	private javax.swing.JTextField personSerialField;
	private javax.swing.JButton personSaveButton;
	private javax.swing.JPanel jPanel16;
	private javax.swing.JButton personMainButton;
	private javax.swing.JPanel jPanel4;
	private javax.swing.JPanel jPanel17;
	private javax.swing.JPanel jPanel18;
	private javax.swing.JRadioButton roleDatabaseSelector;
	private javax.swing.JRadioButton roleFileSelector;
	private javax.swing.JRadioButton roleStoreSelector;
	private javax.swing.JPanel roleLoadPanel;
	private javax.swing.JPanel jPanel25;
	private javax.swing.JLabel jLabel31;
	private javax.swing.JTextField roleSerialField;
	private javax.swing.JPanel jPanel26;
	private javax.swing.JPanel jPanel20;
	private javax.swing.JLabel jLabel21;
	private javax.swing.JTextField roleFileField;
	private javax.swing.JButton roleFileButton;
	private javax.swing.JPanel jPanel21;
	private javax.swing.JPanel jPanel22;
	private javax.swing.JLabel jLabel22;
	private javax.swing.JTextField roleStoreField;
	private javax.swing.JButton roleStoreButton;
	private javax.swing.JLabel jLabel23;
	private javax.swing.JComboBox roleAliasBox;
	private javax.swing.JButton roleAliasButton;
	private javax.swing.JButton roleLoadButton;
	private javax.swing.JPanel jPanel23;
	private javax.swing.JPanel jPanel24;
	private javax.swing.JLabel jLabel24;
	private javax.swing.JTextField roleInfoCNField;
	private javax.swing.JLabel jLabel25;
	private javax.swing.JTextField roleInfoOUField;
	private javax.swing.JLabel jLabel26;
	private javax.swing.JTextField roleInfoOField;
	private javax.swing.JLabel jLabel27;
	private javax.swing.JTextField roleInfoHashField;
	private javax.swing.JLabel jLabel28;
	private javax.swing.JTextField roleInfoLField;
	private javax.swing.JLabel jLabel29;
	private javax.swing.JTextField roleInfoSTField;
	private javax.swing.JLabel jLabel30;
	private javax.swing.JTextField roleInfoCField;
	private javax.swing.JButton roleInfoButton;
	private javax.swing.JPanel jPanel27;
	private javax.swing.JLabel jLabel32;
	private javax.swing.JPasswordField roleSignField;
	private javax.swing.JLabel jLabel34;
	private javax.swing.JPasswordField roleRoleField;
	private javax.swing.JButton roleSignButton;
	private javax.swing.JPanel jPanel28;
	private javax.swing.JLabel jLabel33;
	private javax.swing.JTextField roleCertField;
	private javax.swing.JButton roleCertButton;
	private javax.swing.JButton roleSaveButton;
	private javax.swing.JPanel jPanel29;
	private javax.swing.JButton roleMainButton;
	private javax.swing.JPanel jPanel5;
	private javax.swing.JPanel jPanel30;
	private javax.swing.JPanel jPanel31;
	private javax.swing.JRadioButton pseudonymDatabaseSelector;
	private javax.swing.JRadioButton pseudonymFileSelector;
	private javax.swing.JRadioButton pseudonymStoreSelector;
	private javax.swing.JPanel pseudonymLoadPanel;
	private javax.swing.JPanel jPanel33;
	private javax.swing.JLabel jLabel36;
	private javax.swing.JTextField pseudonymSerialField;
	private javax.swing.JPanel jPanel34;
	private javax.swing.JPanel jPanel35;
	private javax.swing.JLabel jLabel37;
	private javax.swing.JTextField pseudonymFileField;
	private javax.swing.JButton pseudonymFileButton;
	private javax.swing.JPanel jPanel36;
	private javax.swing.JPanel jPanel37;
	private javax.swing.JLabel jLabel38;
	private javax.swing.JTextField pseudonymStoreField;
	private javax.swing.JButton pseudonymStoreButton;
	private javax.swing.JLabel jLabel39;
	private javax.swing.JComboBox pseudonymAliasBox;
	private javax.swing.JButton pseudonymAliasButton;
	private javax.swing.JButton pseudonymLoadButton;
	private javax.swing.JPanel jPanel38;
	private javax.swing.JPanel jPanel39;
	private javax.swing.JLabel jLabel40;
	private javax.swing.JTextField pseudonymInfoCNField;
	private javax.swing.JLabel jLabel41;
	private javax.swing.JTextField pseudonymInfoOUField;
	private javax.swing.JLabel jLabel42;
	private javax.swing.JTextField pseudonymInfoOField;
	private javax.swing.JLabel jLabel43;
	private javax.swing.JTextField pseudonymInfoHashField;
	private javax.swing.JLabel jLabel44;
	private javax.swing.JTextField pseudonymInfoLField;
	private javax.swing.JLabel jLabel45;
	private javax.swing.JTextField pseudonymInfoSTField;
	private javax.swing.JLabel jLabel46;
	private javax.swing.JTextField pseudonymInfoCField;
	private javax.swing.JButton pseudonymInfoButton;
	private javax.swing.JPanel jPanel40;
	private javax.swing.JLabel jLabel47;
	private javax.swing.JPasswordField pseudonymSignField;
	private javax.swing.JButton pseudonymSignButton;
	private javax.swing.JPanel jPanel41;
	private javax.swing.JLabel jLabel48;
	private javax.swing.JTextField pseudonymCertField;
	private javax.swing.JButton pseudonymCertButton;
	private javax.swing.JButton pseudonymSaveButton;
	private javax.swing.JPanel jPanel42;
	private javax.swing.JButton pseudonymMainButton;
	private javax.swing.JLabel jLabel1;
	// End of variables declaration//GEN-END:variables

}
