package pki;

import java.awt.*;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.util.Properties;

import javax.swing.*;
import javax.swing.border.TitledBorder;

/**
 * Dialog for changing the PKI's settings.
 *
 * @author Sebastian Clau
 * @version 0.1
 */

public class PKISettingsDialog extends JDialog implements ActionListener {

	private Properties settings = null;

	public PKISettingsDialog(Properties settings) {
		this.settings = settings;
		initDialog();
	}

	public void start() {
		this.pack();
		this.show();
	}

	public void actionPerformed(ActionEvent ae) {
		if (ae.getSource() == cancelButton) {
			this.dispose();
		} else if (ae.getSource() == okButton) {
			if (checkNewSettings()) {
				this.dispose();
				if (checkSettingsChanged()) {
					storeSettings();
					Main.saveSettings();
					Main.start();
				}
			}
		} else if (ae.getSource() == initDBButton) {
			if (checkNewSettings()) {
				if (JOptionPane
					.showConfirmDialog(
						this,
						"Initialization of the database erases\n"
							+ "all data previously stored in that database.\n\n"
							+ "Do you want to proceed?",
						"Warning",
						JOptionPane.YES_NO_OPTION)
					== JOptionPane.YES_OPTION) {
					if (checkSettingsChanged()) {
						storeSettings();
						Main.saveSettings();
					}
					try {
						Main.initDB();
					} catch (Exception e) {
						try {
							JOptionPane.showMessageDialog(
								this,
								"Initialization of Database failed:\n\n"
									+ e.getMessage(),
								"Initialization error",
								JOptionPane.ERROR_MESSAGE);
							e.printStackTrace();
						} catch (Exception e2) {
						}
					}
				}
			}
		}
	}

	private boolean checkNewSettings() {
		// check settings
		boolean settingsOK = true;
		try {
			new Integer(mysqlPortField.getText());
		} catch (Exception e) {
			settingsOK = false;
			try {
				JOptionPane.showMessageDialog(
					this,
					"'MySQP Port' must be an integer value.",
					"Settings error",
					JOptionPane.ERROR_MESSAGE);
			} catch (Exception e2) {
			}
		}
		return settingsOK;
	}

	private boolean checkSettingsChanged() {
		if ((!settings
			.getProperty(Main.keyStoreFileName)
			.equals(keyStoreFileNameField.getText()))
			|| (!settings
				.getProperty(Main.keyStorePassword)
				.equals(new String(keyStorePasswordField.getPassword())))
			|| (!settings
				.getProperty(Main.secretKeyPassword)
				.equals(new String(secretKeyPasswordField.getPassword())))
			|| (settings.getProperty(Main.dbType).equals("file")
				&& (!dbTypeFileButton.isSelected()))
			|| (settings.getProperty(Main.dbType).equals("mysql")
				&& (!dbTypeMysqlButton.isSelected()))
			|| (!settings
				.getProperty(Main.fileDBFileName)
				.equals(fileDBFileNameField.getText()))
			|| (!settings
				.getProperty(Main.mysqlHost)
				.equals(mysqlHostField.getText()))
			|| (!settings
				.getProperty(Main.mysqlPort)
				.equals(mysqlPortField.getText()))
			|| (!settings
				.getProperty(Main.mysqlDBName)
				.equals(mysqlDBNameField.getText()))
			|| (!settings
				.getProperty(Main.mysqlUsername)
				.equals(mysqlUsernameField.getText()))
			|| (!settings
				.getProperty(Main.mysqlPassword)
				.equals(new String(mysqlPasswordField.getPassword())))) {
			return true;
		} else {
			return false;
		}
	}

	/** Stores Settings typed by the user
	 */
	private void storeSettings() {
		settings.setProperty(
			Main.keyStoreFileName,
			keyStoreFileNameField.getText());
		settings.setProperty(
			Main.keyStorePassword,
			new String(keyStorePasswordField.getPassword()));
		settings.setProperty(
			Main.secretKeyPassword,
			new String(secretKeyPasswordField.getPassword()));
		if (dbTypeFileButton.isSelected()) {
			settings.setProperty(Main.dbType, "file");
		} else {
			settings.setProperty(Main.dbType, "mysql");
		}
		settings.setProperty(
			Main.fileDBFileName,
			fileDBFileNameField.getText());
		settings.setProperty(Main.mysqlHost, mysqlHostField.getText());
		settings.setProperty(Main.mysqlPort, mysqlPortField.getText());
		settings.setProperty(Main.mysqlDBName, mysqlDBNameField.getText());
		settings.setProperty(Main.mysqlUsername, mysqlUsernameField.getText());
		settings.setProperty(
			Main.mysqlPassword,
			new String(mysqlPasswordField.getPassword()));
	}

	JLabel keyStoreFileNameLabel,
		keyStorePasswordLabel,
		secretKeyPasswordLabel,
		fileDBFileNameLabel,
		mysqlHostLabel,
		mysqlPortLabel,
		mysqlDBNameLabel,
		mysqlUsernameLabel,
		mysqlPasswordLabel;
	JPanel dbTypePanel;
	JTextField keyStoreFileNameField,
		fileDBFileNameField,
		mysqlHostField,
		mysqlPortField,
		mysqlDBNameField,
		mysqlUsernameField;
	JPasswordField keyStorePasswordField,
		secretKeyPasswordField,
		mysqlPasswordField;
	ButtonGroup dbTypeGroup;
	JRadioButton dbTypeFileButton, dbTypeMysqlButton;
	JButton okButton, cancelButton, initDBButton;

	private void initDialog() {
		this.setTitle("Identity-CA Settings");

		GridBagLayout gbl = new GridBagLayout();
		this.getContentPane().setLayout(gbl);

		JPanel keyStorePanel = new JPanel();
		keyStorePanel.setBorder(new TitledBorder(" KeyStore "));
		keyStorePanel.setLayout(gbl);
		gbl.setConstraints(
			keyStorePanel,
			new GridBagConstraints(
				0,
				0,
				2,
				1,
				1,
				1,
				GridBagConstraints.WEST,
				GridBagConstraints.HORIZONTAL,
				new Insets(3, 3, 3, 3),
				0,
				0));
		this.getContentPane().add(keyStorePanel);

		keyStoreFileNameLabel = new JLabel("Filename: ");
		gbl.setConstraints(
			keyStoreFileNameLabel,
			new GridBagConstraints(
				0,
				0,
				1,
				1,
				0,
				1,
				GridBagConstraints.WEST,
				GridBagConstraints.NONE,
				new Insets(3, 3, 3, 3),
				0,
				0));
		keyStorePanel.add(keyStoreFileNameLabel);

		keyStoreFileNameField =
			new JTextField(settings.getProperty(Main.keyStoreFileName));
		gbl.setConstraints(
			keyStoreFileNameField,
			new GridBagConstraints(
				1,
				0,
				1,
				1,
				1,
				1,
				GridBagConstraints.WEST,
				GridBagConstraints.HORIZONTAL,
				new Insets(3, 3, 3, 3),
				0,
				0));
		keyStorePanel.add(keyStoreFileNameField);

		keyStorePasswordLabel = new JLabel("Keystore Password: ");
		gbl.setConstraints(
			keyStorePasswordLabel,
			new GridBagConstraints(
				0,
				1,
				1,
				1,
				0,
				1,
				GridBagConstraints.WEST,
				GridBagConstraints.NONE,
				new Insets(3, 3, 3, 3),
				0,
				0));
		keyStorePanel.add(keyStorePasswordLabel);

		keyStorePasswordField =
			new JPasswordField(settings.getProperty(Main.keyStorePassword));
		gbl.setConstraints(
			keyStorePasswordField,
			new GridBagConstraints(
				1,
				1,
				1,
				1,
				1,
				1,
				GridBagConstraints.WEST,
				GridBagConstraints.HORIZONTAL,
				new Insets(3, 3, 3, 3),
				0,
				0));
		keyStorePanel.add(keyStorePasswordField);

		secretKeyPasswordLabel = new JLabel("Secret Key Password: ");
		gbl.setConstraints(
			secretKeyPasswordLabel,
			new GridBagConstraints(
				0,
				2,
				1,
				1,
				0,
				1,
				GridBagConstraints.WEST,
				GridBagConstraints.NONE,
				new Insets(3, 3, 3, 3),
				0,
				0));
		keyStorePanel.add(secretKeyPasswordLabel);

		secretKeyPasswordField =
			new JPasswordField(settings.getProperty(Main.secretKeyPassword));
		gbl.setConstraints(
			secretKeyPasswordField,
			new GridBagConstraints(
				1,
				2,
				1,
				1,
				1,
				1,
				GridBagConstraints.WEST,
				GridBagConstraints.HORIZONTAL,
				new Insets(3, 3, 3, 3),
				0,
				0));
		keyStorePanel.add(secretKeyPasswordField);

		dbTypePanel = new JPanel();
		dbTypePanel.setBorder(new TitledBorder(" Database type "));
		dbTypePanel.setLayout(new GridLayout(2, 1));
		gbl.setConstraints(
			dbTypePanel,
			new GridBagConstraints(
				0,
				1,
				2,
				1,
				1,
				1,
				GridBagConstraints.WEST,
				GridBagConstraints.HORIZONTAL,
				new Insets(3, 3, 3, 3),
				0,
				0));
		this.getContentPane().add(dbTypePanel);

		dbTypeGroup = new ButtonGroup();
		dbTypeFileButton = new JRadioButton("File");
		dbTypeGroup.add(dbTypeFileButton);
		dbTypePanel.add(dbTypeFileButton);

		dbTypeMysqlButton = new JRadioButton("MySQL Database");
		dbTypeGroup.add(dbTypeMysqlButton);
		dbTypePanel.add(dbTypeMysqlButton);
		if (settings.getProperty(Main.dbType).equals("file")) {
			dbTypeFileButton.setSelected(true);
		} else {
			dbTypeMysqlButton.setSelected(true);
		}

		JPanel fileDBPanel = new JPanel();
		fileDBPanel.setBorder(new TitledBorder(" File Database "));
		fileDBPanel.setLayout(gbl);
		gbl.setConstraints(
			fileDBPanel,
			new GridBagConstraints(
				0,
				2,
				2,
				1,
				1,
				1,
				GridBagConstraints.WEST,
				GridBagConstraints.HORIZONTAL,
				new Insets(3, 3, 3, 3),
				0,
				0));
		this.getContentPane().add(fileDBPanel);

		fileDBFileNameLabel = new JLabel("Filename: ");
		gbl.setConstraints(
			fileDBFileNameLabel,
			new GridBagConstraints(
				0,
				0,
				1,
				1,
				0,
				1,
				GridBagConstraints.WEST,
				GridBagConstraints.NONE,
				new Insets(3, 3, 3, 3),
				0,
				0));
		fileDBPanel.add(fileDBFileNameLabel);

		fileDBFileNameField =
			new JTextField(settings.getProperty(Main.fileDBFileName));
		gbl.setConstraints(
			fileDBFileNameField,
			new GridBagConstraints(
				1,
				0,
				1,
				1,
				1,
				1,
				GridBagConstraints.WEST,
				GridBagConstraints.HORIZONTAL,
				new Insets(3, 3, 3, 3),
				0,
				0));
		fileDBPanel.add(fileDBFileNameField);

		JPanel mysqlPanel = new JPanel();
		mysqlPanel.setBorder(new TitledBorder(" MySQL Database "));
		mysqlPanel.setLayout(gbl);
		gbl.setConstraints(
			mysqlPanel,
			new GridBagConstraints(
				0,
				3,
				2,
				1,
				1,
				1,
				GridBagConstraints.WEST,
				GridBagConstraints.HORIZONTAL,
				new Insets(3, 3, 3, 3),
				0,
				0));
		this.getContentPane().add(mysqlPanel);

		mysqlHostLabel = new JLabel("Host: ");
		gbl.setConstraints(
			mysqlHostLabel,
			new GridBagConstraints(
				0,
				0,
				1,
				1,
				0,
				1,
				GridBagConstraints.WEST,
				GridBagConstraints.NONE,
				new Insets(3, 3, 3, 3),
				0,
				0));
		mysqlPanel.add(mysqlHostLabel);

		mysqlHostField = new JTextField(settings.getProperty(Main.mysqlHost));
		gbl.setConstraints(
			mysqlHostField,
			new GridBagConstraints(
				1,
				0,
				1,
				1,
				1,
				1,
				GridBagConstraints.WEST,
				GridBagConstraints.HORIZONTAL,
				new Insets(3, 3, 3, 3),
				0,
				0));
		mysqlPanel.add(mysqlHostField);

		mysqlPortLabel = new JLabel("Port: ");
		gbl.setConstraints(
			mysqlPortLabel,
			new GridBagConstraints(
				0,
				1,
				1,
				1,
				0,
				1,
				GridBagConstraints.WEST,
				GridBagConstraints.NONE,
				new Insets(3, 3, 3, 3),
				0,
				0));
		mysqlPanel.add(mysqlPortLabel);

		mysqlPortField = new JTextField(settings.getProperty(Main.mysqlPort));
		gbl.setConstraints(
			mysqlPortField,
			new GridBagConstraints(
				1,
				1,
				1,
				1,
				1,
				1,
				GridBagConstraints.WEST,
				GridBagConstraints.HORIZONTAL,
				new Insets(3, 3, 3, 3),
				0,
				0));
		mysqlPanel.add(mysqlPortField);

		mysqlDBNameLabel = new JLabel("Database Name: ");
		gbl.setConstraints(
			mysqlDBNameLabel,
			new GridBagConstraints(
				0,
				2,
				1,
				1,
				0,
				1,
				GridBagConstraints.WEST,
				GridBagConstraints.NONE,
				new Insets(3, 3, 3, 3),
				0,
				0));
		mysqlPanel.add(mysqlDBNameLabel);

		mysqlDBNameField =
			new JTextField(settings.getProperty(Main.mysqlDBName));
		gbl.setConstraints(
			mysqlDBNameField,
			new GridBagConstraints(
				1,
				2,
				1,
				1,
				1,
				1,
				GridBagConstraints.WEST,
				GridBagConstraints.HORIZONTAL,
				new Insets(3, 3, 3, 3),
				0,
				0));
		mysqlPanel.add(mysqlDBNameField);

		mysqlUsernameLabel = new JLabel("Username: ");
		gbl.setConstraints(
			mysqlUsernameLabel,
			new GridBagConstraints(
				0,
				3,
				1,
				1,
				0,
				1,
				GridBagConstraints.WEST,
				GridBagConstraints.NONE,
				new Insets(3, 3, 3, 3),
				0,
				0));
		mysqlPanel.add(mysqlUsernameLabel);

		mysqlUsernameField =
			new JTextField(settings.getProperty(Main.mysqlUsername));
		gbl.setConstraints(
			mysqlUsernameField,
			new GridBagConstraints(
				1,
				3,
				1,
				1,
				1,
				1,
				GridBagConstraints.WEST,
				GridBagConstraints.HORIZONTAL,
				new Insets(3, 3, 3, 3),
				0,
				0));
		mysqlPanel.add(mysqlUsernameField);

		mysqlPasswordLabel = new JLabel("Password: ");
		gbl.setConstraints(
			mysqlPasswordLabel,
			new GridBagConstraints(
				0,
				4,
				1,
				1,
				0,
				1,
				GridBagConstraints.WEST,
				GridBagConstraints.NONE,
				new Insets(3, 3, 3, 3),
				0,
				0));
		mysqlPanel.add(mysqlPasswordLabel);

		mysqlPasswordField =
			new JPasswordField(settings.getProperty(Main.mysqlPassword));
		gbl.setConstraints(
			mysqlPasswordField,
			new GridBagConstraints(
				1,
				4,
				1,
				1,
				1,
				1,
				GridBagConstraints.WEST,
				GridBagConstraints.HORIZONTAL,
				new Insets(3, 3, 3, 3),
				0,
				0));
		mysqlPanel.add(mysqlPasswordField);

		// Buttons
		JSeparator buttonSeparator = new JSeparator();
		gbl.setConstraints(
			buttonSeparator,
			new GridBagConstraints(
				0,
				4,
				2,
				1,
				1,
				1,
				GridBagConstraints.WEST,
				GridBagConstraints.HORIZONTAL,
				new Insets(3, 3, 3, 3),
				0,
				0));
		this.getContentPane().add(buttonSeparator);

		JPanel buttonPanel = new JPanel();
		buttonPanel.setLayout(gbl);
		gbl.setConstraints(
			buttonPanel,
			new GridBagConstraints(
				0,
				5,
				2,
				1,
				1,
				1,
				GridBagConstraints.WEST,
				GridBagConstraints.HORIZONTAL,
				new Insets(3, 3, 3, 3),
				0,
				0));
		this.getContentPane().add(buttonPanel);

		initDBButton = new JButton("Initialize Database");
		gbl.setConstraints(
			initDBButton,
			new GridBagConstraints(
				0,
				0,
				1,
				1,
				1,
				1,
				GridBagConstraints.EAST,
				GridBagConstraints.NONE,
				new Insets(3, 3, 3, 3),
				0,
				0));
		buttonPanel.add(initDBButton);

		cancelButton = new JButton("Cancel");
		gbl.setConstraints(
			cancelButton,
			new GridBagConstraints(
				1,
				0,
				1,
				1,
				1,
				1,
				GridBagConstraints.EAST,
				GridBagConstraints.NONE,
				new Insets(3, 3, 3, 3),
				0,
				0));
		buttonPanel.add(cancelButton);

		okButton = new JButton("OK");
		gbl.setConstraints(
			okButton,
			new GridBagConstraints(
				2,
				0,
				1,
				1,
				1,
				1,
				GridBagConstraints.EAST,
				GridBagConstraints.NONE,
				new Insets(3, 3, 3, 3),
				0,
				0));
		buttonPanel.add(okButton);

		// add ActionListner to Buttons
		initDBButton.addActionListener(this);
		cancelButton.addActionListener(this);
		okButton.addActionListener(this);
	}

	public static void main(String argv[]) {
		Properties settings = new Properties();
		settings.setProperty(Main.keyStoreFileName, "data/pkikeys");
		settings.setProperty(Main.secretKeyPassword, "secret");
		settings.setProperty(Main.keyStorePassword, "secret");
		settings.setProperty(Main.dbType, "mysql");
		settings.setProperty(Main.fileDBFileName, "data/pkidata");
		settings.setProperty(Main.mysqlHost, "localhost");
		settings.setProperty(Main.mysqlPort, "3306");
		settings.setProperty(Main.mysqlDBName, "pki");
		settings.setProperty(Main.mysqlUsername, "pkiadmin");
		settings.setProperty(Main.mysqlPassword, "pkiadmin");
		PKISettingsDialog p = new PKISettingsDialog(settings);
		p.start();
	}
}