/**
 * @version working
 * @author Thomas Kriegelstein
 * $Id: PKIUtils.java,v 1.6 2003/12/16 08:36:58 tk4 Exp $
 */
package pki;

import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.security.KeyStore;
import java.security.cert.CertificateFactory;
import java.security.cert.X509Certificate;
import java.util.*;

/**
 * help class with useful functions for PKI.
 *
 * @author Thomas Kriegelstein
 * @version $Id: PKIUtils.java,v 1.6 2003/12/16 08:36:58 tk4 Exp $
 */
public class PKIUtils {

	public static X509Certificate getFileCertificate(String filename) {
		X509Certificate result = null;
		try {
			FileInputStream fis = new FileInputStream(filename);
			CertificateFactory cf = CertificateFactory.getInstance("X.509");
			result = (X509Certificate)cf.generateCertificate(fis);
		} catch (Exception e) {
			e.printStackTrace();
		}
		return result;
	}

	public static X509Certificate getStoreCertificate(
		String filename,
		String alias) {
		X509Certificate result = null;
		try {
			KeyStore store = loadStore(filename);
			if (store != null) {
				X509Certificate cert =
					(X509Certificate)store.getCertificate(alias);
				result = cert;
			}
		} catch (Exception e) {
			e.printStackTrace();
		}
		return result;
	}

	public static String[] getAliasFromStore(String filename) {
		String[] result = {
		};
		try {
			KeyStore store = loadStore(filename);
			if (store != null) {
				Enumeration e = store.aliases();
				Vector v = new Vector();
				while (e.hasMoreElements())
					v.addElement(e.nextElement());
				result = (String[])v.toArray(result);
			}
		} catch (Exception e) {
			e.printStackTrace();
		}
		return result;
	}

	private static KeyStore loadStore(String filename) {
		KeyStore result = null;
		try {
			KeyStore tmp = KeyStore.getInstance("JKS");
			FileInputStream fis = new FileInputStream(filename);
			tmp.load(fis, null);
			result = tmp;
		} catch (Exception e) {
			e.printStackTrace();
		}
		return result;
	}

	public static void saveCertificate(String filename, X509Certificate cert) {
		try {
			byte[] arr = cert.getEncoded();
			FileOutputStream fos = new FileOutputStream(filename);
			fos.write(arr);
			fos.close();
		} catch (Exception e) {
			e.printStackTrace();
		}
	}

	public static Hashtable decrypt(X509Certificate cert) {
		Hashtable result = new Hashtable();
		String tmp = cert.getSubjectDN().getName();
		StringTokenizer st = new StringTokenizer(tmp, ",");
		while (st.hasMoreTokens()) {
			String token = st.nextToken().trim();
			int i = token.indexOf("=");
			String name = token.substring(0, i);
			String value = token.substring(i + 1);
			result.put(name, value);
		}
		return result;
	}
}
